/****************************************************************************
** Meta object code from reading C++ file 'playlist_widget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../widgets/playlist_widget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlist_widget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__ListPic_t {
    QByteArrayData data[1];
    char stringdata0[13];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__ListPic_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__ListPic_t qt_meta_stringdata_dmr__ListPic = {
    {
QT_MOC_LITERAL(0, 0, 12) // "dmr::ListPic"

    },
    "dmr::ListPic"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__ListPic[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::ListPic::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::ListPic::staticMetaObject = { {
    QMetaObject::SuperData::link<QLabel::staticMetaObject>(),
    qt_meta_stringdata_dmr__ListPic.data,
    qt_meta_data_dmr__ListPic,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::ListPic::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::ListPic::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__ListPic.stringdata0))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int dmr::ListPic::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__PlaylistWidget_t {
    QByteArrayData data[25];
    char stringdata0[328];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__PlaylistWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__PlaylistWidget_t qt_meta_stringdata_dmr__PlaylistWidget = {
    {
QT_MOC_LITERAL(0, 0, 19), // "dmr::PlaylistWidget"
QT_MOC_LITERAL(1, 20, 11), // "stateChange"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 10), // "isShortcut"
QT_MOC_LITERAL(4, 44, 10), // "sizeChange"
QT_MOC_LITERAL(5, 55, 11), // "togglePopup"
QT_MOC_LITERAL(6, 67, 12), // "loadPlaylist"
QT_MOC_LITERAL(7, 80, 12), // "openItemInFM"
QT_MOC_LITERAL(8, 93, 12), // "showItemInfo"
QT_MOC_LITERAL(9, 106, 17), // "removeClickedItem"
QT_MOC_LITERAL(10, 124, 20), // "slotCloseTimeTimeOut"
QT_MOC_LITERAL(11, 145, 13), // "slotCloseItem"
QT_MOC_LITERAL(12, 159, 8), // "QWidget*"
QT_MOC_LITERAL(13, 168, 1), // "w"
QT_MOC_LITERAL(14, 170, 21), // "slotDoubleClickedItem"
QT_MOC_LITERAL(15, 192, 13), // "slotRowsMoved"
QT_MOC_LITERAL(16, 206, 16), // "updateItemStates"
QT_MOC_LITERAL(17, 223, 14), // "updateItemInfo"
QT_MOC_LITERAL(18, 238, 11), // "appendItems"
QT_MOC_LITERAL(19, 250, 10), // "removeItem"
QT_MOC_LITERAL(20, 261, 18), // "slotShowSelectItem"
QT_MOC_LITERAL(21, 280, 16), // "QListWidgetItem*"
QT_MOC_LITERAL(22, 297, 13), // "OnItemChanged"
QT_MOC_LITERAL(23, 311, 7), // "current"
QT_MOC_LITERAL(24, 319, 8) // "previous"

    },
    "dmr::PlaylistWidget\0stateChange\0\0"
    "isShortcut\0sizeChange\0togglePopup\0"
    "loadPlaylist\0openItemInFM\0showItemInfo\0"
    "removeClickedItem\0slotCloseTimeTimeOut\0"
    "slotCloseItem\0QWidget*\0w\0slotDoubleClickedItem\0"
    "slotRowsMoved\0updateItemStates\0"
    "updateItemInfo\0appendItems\0removeItem\0"
    "slotShowSelectItem\0QListWidgetItem*\0"
    "OnItemChanged\0current\0previous"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__PlaylistWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   99,    2, 0x06 /* Public */,
       4,    0,  102,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,  103,    2, 0x0a /* Public */,
       6,    0,  106,    2, 0x0a /* Public */,
       7,    0,  107,    2, 0x0a /* Public */,
       8,    0,  108,    2, 0x0a /* Public */,
       9,    1,  109,    2, 0x0a /* Public */,
      10,    0,  112,    2, 0x0a /* Public */,
      11,    1,  113,    2, 0x0a /* Public */,
      14,    1,  116,    2, 0x0a /* Public */,
      15,    0,  119,    2, 0x0a /* Public */,
      16,    0,  120,    2, 0x09 /* Protected */,
      17,    1,  121,    2, 0x09 /* Protected */,
      18,    0,  124,    2, 0x09 /* Protected */,
      19,    1,  125,    2, 0x09 /* Protected */,
      20,    1,  128,    2, 0x09 /* Protected */,
      22,    2,  131,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 21,    2,
    QMetaType::Void, 0x80000000 | 21, 0x80000000 | 21,   23,   24,

       0        // eod
};

void dmr::PlaylistWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PlaylistWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->stateChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->sizeChange(); break;
        case 2: _t->togglePopup((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->loadPlaylist(); break;
        case 4: _t->openItemInFM(); break;
        case 5: _t->showItemInfo(); break;
        case 6: _t->removeClickedItem((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->slotCloseTimeTimeOut(); break;
        case 8: _t->slotCloseItem((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 9: _t->slotDoubleClickedItem((*reinterpret_cast< QWidget*(*)>(_a[1]))); break;
        case 10: _t->slotRowsMoved(); break;
        case 11: _t->updateItemStates(); break;
        case 12: _t->updateItemInfo((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->appendItems(); break;
        case 14: _t->removeItem((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->slotShowSelectItem((*reinterpret_cast< QListWidgetItem*(*)>(_a[1]))); break;
        case 16: _t->OnItemChanged((*reinterpret_cast< QListWidgetItem*(*)>(_a[1])),(*reinterpret_cast< QListWidgetItem*(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PlaylistWidget::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistWidget::stateChange)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PlaylistWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistWidget::sizeChange)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::PlaylistWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dmr__PlaylistWidget.data,
    qt_meta_data_dmr__PlaylistWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::PlaylistWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::PlaylistWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__PlaylistWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::PlaylistWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void dmr::PlaylistWidget::stateChange(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dmr::PlaylistWidget::sizeChange()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
