/****************************************************************************
** Meta object code from reading C++ file 'dlnacontentserver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../dlna/dlnacontentserver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dlnacontentserver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DlnaContentServer_t {
    QByteArrayData data[12];
    char stringdata0[140];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DlnaContentServer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DlnaContentServer_t qt_meta_stringdata_DlnaContentServer = {
    {
QT_MOC_LITERAL(0, 0, 17), // "DlnaContentServer"
QT_MOC_LITERAL(1, 18, 16), // "contSeqWriteData"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 22), // "std::shared_ptr<QFile>"
QT_MOC_LITERAL(4, 59, 4), // "file"
QT_MOC_LITERAL(5, 64, 4), // "size"
QT_MOC_LITERAL(6, 69, 14), // "QHttpResponse*"
QT_MOC_LITERAL(7, 84, 4), // "resp"
QT_MOC_LITERAL(8, 89, 11), // "closeServer"
QT_MOC_LITERAL(9, 101, 12), // "seqWriteData"
QT_MOC_LITERAL(10, 114, 20), // "initializeHttpServer"
QT_MOC_LITERAL(11, 135, 4) // "port"

    },
    "DlnaContentServer\0contSeqWriteData\0\0"
    "std::shared_ptr<QFile>\0file\0size\0"
    "QHttpResponse*\0resp\0closeServer\0"
    "seqWriteData\0initializeHttpServer\0"
    "port"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DlnaContentServer[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   34,    2, 0x06 /* Public */,
       8,    0,   41,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    3,   42,    2, 0x0a /* Public */,
      10,    1,   49,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::LongLong, 0x80000000 | 6,    4,    5,    7,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::LongLong, 0x80000000 | 6,    4,    5,    7,
    QMetaType::Bool, QMetaType::Int,   11,

       0        // eod
};

void DlnaContentServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DlnaContentServer *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->contSeqWriteData((*reinterpret_cast< std::shared_ptr<QFile>(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2])),(*reinterpret_cast< QHttpResponse*(*)>(_a[3]))); break;
        case 1: _t->closeServer(); break;
        case 2: _t->seqWriteData((*reinterpret_cast< std::shared_ptr<QFile>(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2])),(*reinterpret_cast< QHttpResponse*(*)>(_a[3]))); break;
        case 3: { bool _r = _t->initializeHttpServer((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHttpResponse* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 2:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QHttpResponse* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DlnaContentServer::*)(std::shared_ptr<QFile> , qint64 , QHttpResponse * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DlnaContentServer::contSeqWriteData)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DlnaContentServer::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DlnaContentServer::closeServer)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DlnaContentServer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DlnaContentServer.data,
    qt_meta_data_DlnaContentServer,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DlnaContentServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DlnaContentServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DlnaContentServer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DlnaContentServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void DlnaContentServer::contSeqWriteData(std::shared_ptr<QFile> _t1, qint64 _t2, QHttpResponse * _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DlnaContentServer::closeServer()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
