/****************************************************************************
** Meta object code from reading C++ file 'movieinfo_dialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../widgets/movieinfo_dialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'movieinfo_dialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__PosterFrame_t {
    QByteArrayData data[1];
    char stringdata0[17];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__PosterFrame_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__PosterFrame_t qt_meta_stringdata_dmr__PosterFrame = {
    {
QT_MOC_LITERAL(0, 0, 16) // "dmr::PosterFrame"

    },
    "dmr::PosterFrame"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__PosterFrame[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::PosterFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::PosterFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QLabel::staticMetaObject>(),
    qt_meta_stringdata_dmr__PosterFrame.data,
    qt_meta_data_dmr__PosterFrame,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::PosterFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::PosterFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__PosterFrame.stringdata0))
        return static_cast<void*>(this);
    return QLabel::qt_metacast(_clname);
}

int dmr::PosterFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLabel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__InfoBottom_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__InfoBottom_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__InfoBottom_t qt_meta_stringdata_dmr__InfoBottom = {
    {
QT_MOC_LITERAL(0, 0, 15) // "dmr::InfoBottom"

    },
    "dmr::InfoBottom"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__InfoBottom[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::InfoBottom::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::InfoBottom::staticMetaObject = { {
    QMetaObject::SuperData::link<DFrame::staticMetaObject>(),
    qt_meta_stringdata_dmr__InfoBottom.data,
    qt_meta_data_dmr__InfoBottom,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::InfoBottom::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::InfoBottom::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__InfoBottom.stringdata0))
        return static_cast<void*>(this);
    return DFrame::qt_metacast(_clname);
}

int dmr::InfoBottom::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFrame::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__ArrowLine_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__ArrowLine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__ArrowLine_t qt_meta_stringdata_dmr__ArrowLine = {
    {
QT_MOC_LITERAL(0, 0, 14) // "dmr::ArrowLine"

    },
    "dmr::ArrowLine"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__ArrowLine[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::ArrowLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::ArrowLine::staticMetaObject = { {
    QMetaObject::SuperData::link<DArrowLineDrawer::staticMetaObject>(),
    qt_meta_stringdata_dmr__ArrowLine.data,
    qt_meta_data_dmr__ArrowLine,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::ArrowLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::ArrowLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__ArrowLine.stringdata0))
        return static_cast<void*>(this);
    return DArrowLineDrawer::qt_metacast(_clname);
}

int dmr::ArrowLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DArrowLineDrawer::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__MovieInfoDialog_t {
    QByteArrayData data[6];
    char stringdata0[76];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__MovieInfoDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__MovieInfoDialog_t qt_meta_stringdata_dmr__MovieInfoDialog = {
    {
QT_MOC_LITERAL(0, 0, 20), // "dmr::MovieInfoDialog"
QT_MOC_LITERAL(1, 21, 13), // "onFontChanged"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 4), // "font"
QT_MOC_LITERAL(4, 41, 13), // "changedHeight"
QT_MOC_LITERAL(5, 55, 20) // "slotThemeTypeChanged"

    },
    "dmr::MovieInfoDialog\0onFontChanged\0\0"
    "font\0changedHeight\0slotThemeTypeChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__MovieInfoDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x08 /* Private */,
       4,    1,   32,    2, 0x08 /* Private */,
       5,    0,   35,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QFont,    3,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,

       0        // eod
};

void dmr::MovieInfoDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MovieInfoDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->onFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 1: _t->changedHeight((*reinterpret_cast< const int(*)>(_a[1]))); break;
        case 2: _t->slotThemeTypeChanged(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::MovieInfoDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<DDialog::staticMetaObject>(),
    qt_meta_stringdata_dmr__MovieInfoDialog.data,
    qt_meta_data_dmr__MovieInfoDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::MovieInfoDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::MovieInfoDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__MovieInfoDialog.stringdata0))
        return static_cast<void*>(this);
    return DDialog::qt_metacast(_clname);
}

int dmr::MovieInfoDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
