/****************************************************************************
** Meta object code from reading C++ file 'mpv_proxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../backends/mpv/mpv_proxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mpv_proxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__MpvProxy_t {
    QByteArrayData data[22];
    char stringdata0[230];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__MpvProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__MpvProxy_t qt_meta_stringdata_dmr__MpvProxy = {
    {
QT_MOC_LITERAL(0, 0, 13), // "dmr::MpvProxy"
QT_MOC_LITERAL(1, 14, 14), // "has_mpv_events"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 10), // "crashCheck"
QT_MOC_LITERAL(4, 41, 4), // "play"
QT_MOC_LITERAL(5, 46, 11), // "pauseResume"
QT_MOC_LITERAL(6, 58, 4), // "stop"
QT_MOC_LITERAL(7, 63, 11), // "seekForward"
QT_MOC_LITERAL(8, 75, 5), // "nSecs"
QT_MOC_LITERAL(9, 81, 12), // "seekBackward"
QT_MOC_LITERAL(10, 94, 12), // "seekAbsolute"
QT_MOC_LITERAL(11, 107, 4), // "nPos"
QT_MOC_LITERAL(12, 112, 8), // "volumeUp"
QT_MOC_LITERAL(13, 121, 10), // "volumeDown"
QT_MOC_LITERAL(14, 132, 12), // "changeVolume"
QT_MOC_LITERAL(15, 145, 4), // "nVol"
QT_MOC_LITERAL(16, 150, 10), // "toggleMute"
QT_MOC_LITERAL(17, 161, 7), // "setMute"
QT_MOC_LITERAL(18, 169, 5), // "bMute"
QT_MOC_LITERAL(19, 175, 17), // "handle_mpv_events"
QT_MOC_LITERAL(20, 193, 19), // "stepBurstScreenshot"
QT_MOC_LITERAL(21, 213, 16) // "slotStateChanged"

    },
    "dmr::MpvProxy\0has_mpv_events\0\0crashCheck\0"
    "play\0pauseResume\0stop\0seekForward\0"
    "nSecs\0seekBackward\0seekAbsolute\0nPos\0"
    "volumeUp\0volumeDown\0changeVolume\0nVol\0"
    "toggleMute\0setMute\0bMute\0handle_mpv_events\0"
    "stepBurstScreenshot\0slotStateChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__MpvProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x06 /* Public */,
       3,    0,   95,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   96,    2, 0x0a /* Public */,
       5,    0,   97,    2, 0x0a /* Public */,
       6,    0,   98,    2, 0x0a /* Public */,
       7,    1,   99,    2, 0x0a /* Public */,
       9,    1,  102,    2, 0x0a /* Public */,
      10,    1,  105,    2, 0x0a /* Public */,
      12,    0,  108,    2, 0x0a /* Public */,
      13,    0,  109,    2, 0x0a /* Public */,
      14,    1,  110,    2, 0x0a /* Public */,
      16,    0,  113,    2, 0x0a /* Public */,
      17,    1,  114,    2, 0x0a /* Public */,
      19,    0,  117,    2, 0x09 /* Protected */,
      20,    0,  118,    2, 0x09 /* Protected */,
      21,    0,  119,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,    8,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   15,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void dmr::MpvProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MpvProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->has_mpv_events(); break;
        case 1: _t->crashCheck(); break;
        case 2: _t->play(); break;
        case 3: _t->pauseResume(); break;
        case 4: _t->stop(); break;
        case 5: _t->seekForward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->seekBackward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->seekAbsolute((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->volumeUp(); break;
        case 9: _t->volumeDown(); break;
        case 10: _t->changeVolume((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->toggleMute(); break;
        case 12: _t->setMute((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->handle_mpv_events(); break;
        case 14: _t->stepBurstScreenshot(); break;
        case 15: _t->slotStateChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MpvProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MpvProxy::has_mpv_events)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MpvProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MpvProxy::crashCheck)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::MpvProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<Backend::staticMetaObject>(),
    qt_meta_stringdata_dmr__MpvProxy.data,
    qt_meta_data_dmr__MpvProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::MpvProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::MpvProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__MpvProxy.stringdata0))
        return static_cast<void*>(this);
    return Backend::qt_metacast(_clname);
}

int dmr::MpvProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Backend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void dmr::MpvProxy::has_mpv_events()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::MpvProxy::crashCheck()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
