/****************************************************************************
** Meta object code from reading C++ file 'presenter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../vendor/presenter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'presenter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Presenter_t {
    QByteArrayData data[21];
    char stringdata0[268];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Presenter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Presenter_t qt_meta_stringdata_Presenter = {
    {
QT_MOC_LITERAL(0, 0, 9), // "Presenter"
QT_MOC_LITERAL(1, 10, 8), // "slotplay"
QT_MOC_LITERAL(2, 19, 0), // ""
QT_MOC_LITERAL(3, 20, 9), // "slotpause"
QT_MOC_LITERAL(4, 30, 12), // "slotplaynext"
QT_MOC_LITERAL(5, 43, 12), // "slotplayprev"
QT_MOC_LITERAL(6, 56, 19), // "slotvolumeRequested"
QT_MOC_LITERAL(7, 76, 6), // "volume"
QT_MOC_LITERAL(8, 83, 20), // "slotopenUrlRequested"
QT_MOC_LITERAL(9, 104, 3), // "url"
QT_MOC_LITERAL(10, 108, 16), // "slotstateChanged"
QT_MOC_LITERAL(11, 125, 23), // "slotloopStatusRequested"
QT_MOC_LITERAL(12, 149, 17), // "Mpris::LoopStatus"
QT_MOC_LITERAL(13, 167, 10), // "loopStatus"
QT_MOC_LITERAL(14, 178, 19), // "slotplayModeChanged"
QT_MOC_LITERAL(15, 198, 23), // "PlaylistModel::PlayMode"
QT_MOC_LITERAL(16, 222, 2), // "pm"
QT_MOC_LITERAL(17, 225, 17), // "slotvolumeChanged"
QT_MOC_LITERAL(18, 243, 8), // "slotseek"
QT_MOC_LITERAL(19, 252, 6), // "Offset"
QT_MOC_LITERAL(20, 259, 8) // "slotstop"

    },
    "Presenter\0slotplay\0\0slotpause\0"
    "slotplaynext\0slotplayprev\0slotvolumeRequested\0"
    "volume\0slotopenUrlRequested\0url\0"
    "slotstateChanged\0slotloopStatusRequested\0"
    "Mpris::LoopStatus\0loopStatus\0"
    "slotplayModeChanged\0PlaylistModel::PlayMode\0"
    "pm\0slotvolumeChanged\0slotseek\0Offset\0"
    "slotstop"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Presenter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   74,    2, 0x0a /* Public */,
       3,    0,   75,    2, 0x0a /* Public */,
       4,    0,   76,    2, 0x0a /* Public */,
       5,    0,   77,    2, 0x0a /* Public */,
       6,    1,   78,    2, 0x0a /* Public */,
       8,    1,   81,    2, 0x0a /* Public */,
      10,    0,   84,    2, 0x0a /* Public */,
      11,    1,   85,    2, 0x0a /* Public */,
      14,    1,   88,    2, 0x0a /* Public */,
      17,    0,   91,    2, 0x0a /* Public */,
      18,    1,   92,    2, 0x0a /* Public */,
      20,    0,   95,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Double,    7,
    QMetaType::Void, QMetaType::QUrl,    9,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,   19,
    QMetaType::Void,

       0        // eod
};

void Presenter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Presenter *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotplay(); break;
        case 1: _t->slotpause(); break;
        case 2: _t->slotplaynext(); break;
        case 3: _t->slotplayprev(); break;
        case 4: _t->slotvolumeRequested((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 5: _t->slotopenUrlRequested((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 6: _t->slotstateChanged(); break;
        case 7: _t->slotloopStatusRequested((*reinterpret_cast< Mpris::LoopStatus(*)>(_a[1]))); break;
        case 8: _t->slotplayModeChanged((*reinterpret_cast< PlaylistModel::PlayMode(*)>(_a[1]))); break;
        case 9: _t->slotvolumeChanged(); break;
        case 10: _t->slotseek((*reinterpret_cast< qlonglong(*)>(_a[1]))); break;
        case 11: _t->slotstop(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Presenter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Presenter.data,
    qt_meta_data_Presenter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Presenter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Presenter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Presenter.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Presenter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
