// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include "player_backend.h"

namespace dmr {
Backend::DebugLevel Backend::_debugLevel = Backend::DebugLevel::Info;
}
