/****************************************************************************
** Meta object code from reading C++ file 'playlist_model.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../libdmr/playlist_model.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlist_model.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__PlaylistModel_t {
    QByteArrayData data[24];
    char stringdata0[310];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__PlaylistModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__PlaylistModel_t qt_meta_stringdata_dmr__PlaylistModel = {
    {
QT_MOC_LITERAL(0, 0, 18), // "dmr::PlaylistModel"
QT_MOC_LITERAL(1, 19, 12), // "countChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 14), // "currentChanged"
QT_MOC_LITERAL(4, 48, 11), // "itemRemoved"
QT_MOC_LITERAL(5, 60, 13), // "itemsAppended"
QT_MOC_LITERAL(6, 74, 7), // "emptied"
QT_MOC_LITERAL(7, 82, 15), // "playModeChanged"
QT_MOC_LITERAL(8, 98, 8), // "PlayMode"
QT_MOC_LITERAL(9, 107, 19), // "asyncAppendFinished"
QT_MOC_LITERAL(10, 127, 19), // "QList<PlayItemInfo>"
QT_MOC_LITERAL(11, 147, 15), // "itemInfoUpdated"
QT_MOC_LITERAL(12, 163, 2), // "id"
QT_MOC_LITERAL(13, 166, 14), // "updateDuration"
QT_MOC_LITERAL(14, 181, 13), // "changeCurrent"
QT_MOC_LITERAL(15, 195, 18), // "delayedAppendAsync"
QT_MOC_LITERAL(16, 214, 11), // "QList<QUrl>"
QT_MOC_LITERAL(17, 226, 9), // "clearLoad"
QT_MOC_LITERAL(18, 236, 15), // "onAsyncFinished"
QT_MOC_LITERAL(19, 252, 13), // "onAsyncUpdate"
QT_MOC_LITERAL(20, 266, 12), // "PlayItemInfo"
QT_MOC_LITERAL(21, 279, 16), // "slotStateChanged"
QT_MOC_LITERAL(22, 296, 5), // "count"
QT_MOC_LITERAL(23, 302, 7) // "current"

    },
    "dmr::PlaylistModel\0countChanged\0\0"
    "currentChanged\0itemRemoved\0itemsAppended\0"
    "emptied\0playModeChanged\0PlayMode\0"
    "asyncAppendFinished\0QList<PlayItemInfo>\0"
    "itemInfoUpdated\0id\0updateDuration\0"
    "changeCurrent\0delayedAppendAsync\0"
    "QList<QUrl>\0clearLoad\0onAsyncFinished\0"
    "onAsyncUpdate\0PlayItemInfo\0slotStateChanged\0"
    "count\0current"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__PlaylistModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       2,  118, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   89,    2, 0x06 /* Public */,
       3,    0,   90,    2, 0x06 /* Public */,
       4,    1,   91,    2, 0x06 /* Public */,
       5,    0,   94,    2, 0x06 /* Public */,
       6,    0,   95,    2, 0x06 /* Public */,
       7,    1,   96,    2, 0x06 /* Public */,
       9,    1,   99,    2, 0x06 /* Public */,
      11,    1,  102,    2, 0x06 /* Public */,
      13,    0,  105,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    1,  106,    2, 0x0a /* Public */,
      15,    1,  109,    2, 0x0a /* Public */,
      17,    0,  112,    2, 0x0a /* Public */,
      18,    0,  113,    2, 0x08 /* Private */,
      19,    1,  114,    2, 0x08 /* Private */,
      21,    0,  117,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 16,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,    2,
    QMetaType::Void,

 // properties: name, type, flags
      22, QMetaType::Int, 0x00495001,
      23, QMetaType::Int, 0x00495003,

 // properties: notify_signal_id
       0,
       1,

       0        // eod
};

void dmr::PlaylistModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PlaylistModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->countChanged(); break;
        case 1: _t->currentChanged(); break;
        case 2: _t->itemRemoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->itemsAppended(); break;
        case 4: _t->emptied(); break;
        case 5: _t->playModeChanged((*reinterpret_cast< PlayMode(*)>(_a[1]))); break;
        case 6: _t->asyncAppendFinished((*reinterpret_cast< const QList<PlayItemInfo>(*)>(_a[1]))); break;
        case 7: _t->itemInfoUpdated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->updateDuration(); break;
        case 9: _t->changeCurrent((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->delayedAppendAsync((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 11: _t->clearLoad(); break;
        case 12: _t->onAsyncFinished(); break;
        case 13: _t->onAsyncUpdate((*reinterpret_cast< PlayItemInfo(*)>(_a[1]))); break;
        case 14: _t->slotStateChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PlaylistModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::countChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::currentChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::itemRemoved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::itemsAppended)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::emptied)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)(PlayMode );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::playModeChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)(const QList<PlayItemInfo> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::asyncAppendFinished)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::itemInfoUpdated)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (PlaylistModel::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlaylistModel::updateDuration)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<PlaylistModel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast< int*>(_v) = _t->current(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<PlaylistModel *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->changeCurrent(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject dmr::PlaylistModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dmr__PlaylistModel.data,
    qt_meta_data_dmr__PlaylistModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::PlaylistModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::PlaylistModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__PlaylistModel.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dmr::PlaylistModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void dmr::PlaylistModel::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::PlaylistModel::currentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dmr::PlaylistModel::itemRemoved(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void dmr::PlaylistModel::itemsAppended()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dmr::PlaylistModel::emptied()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dmr::PlaylistModel::playModeChanged(PlayMode _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void dmr::PlaylistModel::asyncAppendFinished(const QList<PlayItemInfo> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void dmr::PlaylistModel::itemInfoUpdated(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void dmr::PlaylistModel::updateDuration()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
struct qt_meta_stringdata_dmr__LoadThread_t {
    QByteArrayData data[1];
    char stringdata0[16];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__LoadThread_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__LoadThread_t qt_meta_stringdata_dmr__LoadThread = {
    {
QT_MOC_LITERAL(0, 0, 15) // "dmr::LoadThread"

    },
    "dmr::LoadThread"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__LoadThread[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::LoadThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::LoadThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_meta_stringdata_dmr__LoadThread.data,
    qt_meta_data_dmr__LoadThread,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::LoadThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::LoadThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__LoadThread.stringdata0))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int dmr::LoadThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__GetThumanbil_t {
    QByteArrayData data[4];
    char stringdata0[43];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__GetThumanbil_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__GetThumanbil_t qt_meta_stringdata_dmr__GetThumanbil = {
    {
QT_MOC_LITERAL(0, 0, 17), // "dmr::GetThumanbil"
QT_MOC_LITERAL(1, 18, 10), // "updateItem"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 12) // "PlayItemInfo"

    },
    "dmr::GetThumanbil\0updateItem\0\0"
    "PlayItemInfo"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__GetThumanbil[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

       0        // eod
};

void dmr::GetThumanbil::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<GetThumanbil *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateItem((*reinterpret_cast< PlayItemInfo(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (GetThumanbil::*)(PlayItemInfo );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&GetThumanbil::updateItem)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::GetThumanbil::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_meta_stringdata_dmr__GetThumanbil.data,
    qt_meta_data_dmr__GetThumanbil,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::GetThumanbil::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::GetThumanbil::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__GetThumanbil.stringdata0))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int dmr::GetThumanbil::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dmr::GetThumanbil::updateItem(PlayItemInfo _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
