/****************************************************************************
** Meta object code from reading C++ file 'actions.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../common/actions.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actions.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__ActionFactory_t {
    QByteArrayData data[82];
    char stringdata0[1079];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__ActionFactory_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__ActionFactory_t qt_meta_stringdata_dmr__ActionFactory = {
    {
QT_MOC_LITERAL(0, 0, 18), // "dmr::ActionFactory"
QT_MOC_LITERAL(1, 19, 15), // "frameMenuEnable"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 19), // "playSpeedMenuEnable"
QT_MOC_LITERAL(4, 56, 18), // "subtitleMenuEnable"
QT_MOC_LITERAL(5, 75, 15), // "soundMenuEnable"
QT_MOC_LITERAL(6, 91, 10), // "ActionKind"
QT_MOC_LITERAL(7, 102, 7), // "Invalid"
QT_MOC_LITERAL(8, 110, 8), // "OpenFile"
QT_MOC_LITERAL(9, 119, 12), // "OpenFileList"
QT_MOC_LITERAL(10, 132, 13), // "OpenDirectory"
QT_MOC_LITERAL(11, 146, 9), // "StartPlay"
QT_MOC_LITERAL(12, 156, 8), // "Settings"
QT_MOC_LITERAL(13, 165, 5), // "About"
QT_MOC_LITERAL(14, 171, 4), // "Help"
QT_MOC_LITERAL(15, 176, 4), // "Exit"
QT_MOC_LITERAL(16, 181, 14), // "TogglePlaylist"
QT_MOC_LITERAL(17, 196, 13), // "EmptyPlaylist"
QT_MOC_LITERAL(18, 210, 18), // "PlaylistRemoveItem"
QT_MOC_LITERAL(19, 229, 20), // "PlaylistOpenItemInFM"
QT_MOC_LITERAL(20, 250, 16), // "PlaylistItemInfo"
QT_MOC_LITERAL(21, 267, 9), // "MovieInfo"
QT_MOC_LITERAL(22, 277, 7), // "OpenUrl"
QT_MOC_LITERAL(23, 285, 9), // "OpenCdrom"
QT_MOC_LITERAL(24, 295, 16), // "ToggleFullscreen"
QT_MOC_LITERAL(25, 312, 14), // "QuitFullscreen"
QT_MOC_LITERAL(26, 327, 14), // "ToggleMiniMode"
QT_MOC_LITERAL(27, 342, 11), // "WindowAbove"
QT_MOC_LITERAL(28, 354, 12), // "LoadSubtitle"
QT_MOC_LITERAL(29, 367, 14), // "SelectSubtitle"
QT_MOC_LITERAL(30, 382, 12), // "HideSubtitle"
QT_MOC_LITERAL(31, 395, 19), // "MatchOnlineSubtitle"
QT_MOC_LITERAL(32, 415, 17), // "ChangeSubCodepage"
QT_MOC_LITERAL(33, 433, 10), // "Screenshot"
QT_MOC_LITERAL(34, 444, 15), // "BurstScreenshot"
QT_MOC_LITERAL(35, 460, 20), // "GoToScreenshotSolder"
QT_MOC_LITERAL(36, 481, 11), // "SeekForward"
QT_MOC_LITERAL(37, 493, 16), // "SeekForwardLarge"
QT_MOC_LITERAL(38, 510, 12), // "SeekBackward"
QT_MOC_LITERAL(39, 523, 17), // "SeekBackwardLarge"
QT_MOC_LITERAL(40, 541, 12), // "SeekAbsolute"
QT_MOC_LITERAL(41, 554, 11), // "TogglePause"
QT_MOC_LITERAL(42, 566, 4), // "Stop"
QT_MOC_LITERAL(43, 571, 13), // "AccelPlayback"
QT_MOC_LITERAL(44, 585, 13), // "DecelPlayback"
QT_MOC_LITERAL(45, 599, 13), // "ResetPlayback"
QT_MOC_LITERAL(46, 613, 8), // "SubDelay"
QT_MOC_LITERAL(47, 622, 10), // "SubForward"
QT_MOC_LITERAL(48, 633, 9), // "OrderPlay"
QT_MOC_LITERAL(49, 643, 11), // "ShufflePlay"
QT_MOC_LITERAL(50, 655, 10), // "SinglePlay"
QT_MOC_LITERAL(51, 666, 10), // "SingleLoop"
QT_MOC_LITERAL(52, 677, 8), // "ListLoop"
QT_MOC_LITERAL(53, 686, 18), // "ZeroPointFiveTimes"
QT_MOC_LITERAL(54, 705, 8), // "OneTimes"
QT_MOC_LITERAL(55, 714, 16), // "OnePointTwoTimes"
QT_MOC_LITERAL(56, 731, 17), // "OnePointFiveTimes"
QT_MOC_LITERAL(57, 749, 6), // "Double"
QT_MOC_LITERAL(58, 756, 12), // "DefaultFrame"
QT_MOC_LITERAL(59, 769, 13), // "Ratio4x3Frame"
QT_MOC_LITERAL(60, 783, 14), // "Ratio16x9Frame"
QT_MOC_LITERAL(61, 798, 15), // "Ratio16x10Frame"
QT_MOC_LITERAL(62, 814, 15), // "Ratio185x1Frame"
QT_MOC_LITERAL(63, 830, 15), // "Ratio235x1Frame"
QT_MOC_LITERAL(64, 846, 14), // "ClockwiseFrame"
QT_MOC_LITERAL(65, 861, 21), // "CounterclockwiseFrame"
QT_MOC_LITERAL(66, 883, 9), // "NextFrame"
QT_MOC_LITERAL(67, 893, 13), // "PreviousFrame"
QT_MOC_LITERAL(68, 907, 6), // "Stereo"
QT_MOC_LITERAL(69, 914, 11), // "LeftChannel"
QT_MOC_LITERAL(70, 926, 12), // "RightChannel"
QT_MOC_LITERAL(71, 939, 9), // "LoadTrack"
QT_MOC_LITERAL(72, 949, 11), // "SelectTrack"
QT_MOC_LITERAL(73, 961, 16), // "GotoPlaylistNext"
QT_MOC_LITERAL(74, 978, 16), // "GotoPlaylistPrev"
QT_MOC_LITERAL(75, 995, 20), // "GotoPlaylistSelected"
QT_MOC_LITERAL(76, 1016, 8), // "VolumeUp"
QT_MOC_LITERAL(77, 1025, 10), // "VolumeDown"
QT_MOC_LITERAL(78, 1036, 10), // "ToggleMute"
QT_MOC_LITERAL(79, 1047, 12), // "ChangeVolume"
QT_MOC_LITERAL(80, 1060, 12), // "ViewShortcut"
QT_MOC_LITERAL(81, 1073, 5) // "Hwdec"

    },
    "dmr::ActionFactory\0frameMenuEnable\0\0"
    "playSpeedMenuEnable\0subtitleMenuEnable\0"
    "soundMenuEnable\0ActionKind\0Invalid\0"
    "OpenFile\0OpenFileList\0OpenDirectory\0"
    "StartPlay\0Settings\0About\0Help\0Exit\0"
    "TogglePlaylist\0EmptyPlaylist\0"
    "PlaylistRemoveItem\0PlaylistOpenItemInFM\0"
    "PlaylistItemInfo\0MovieInfo\0OpenUrl\0"
    "OpenCdrom\0ToggleFullscreen\0QuitFullscreen\0"
    "ToggleMiniMode\0WindowAbove\0LoadSubtitle\0"
    "SelectSubtitle\0HideSubtitle\0"
    "MatchOnlineSubtitle\0ChangeSubCodepage\0"
    "Screenshot\0BurstScreenshot\0"
    "GoToScreenshotSolder\0SeekForward\0"
    "SeekForwardLarge\0SeekBackward\0"
    "SeekBackwardLarge\0SeekAbsolute\0"
    "TogglePause\0Stop\0AccelPlayback\0"
    "DecelPlayback\0ResetPlayback\0SubDelay\0"
    "SubForward\0OrderPlay\0ShufflePlay\0"
    "SinglePlay\0SingleLoop\0ListLoop\0"
    "ZeroPointFiveTimes\0OneTimes\0"
    "OnePointTwoTimes\0OnePointFiveTimes\0"
    "Double\0DefaultFrame\0Ratio4x3Frame\0"
    "Ratio16x9Frame\0Ratio16x10Frame\0"
    "Ratio185x1Frame\0Ratio235x1Frame\0"
    "ClockwiseFrame\0CounterclockwiseFrame\0"
    "NextFrame\0PreviousFrame\0Stereo\0"
    "LeftChannel\0RightChannel\0LoadTrack\0"
    "SelectTrack\0GotoPlaylistNext\0"
    "GotoPlaylistPrev\0GotoPlaylistSelected\0"
    "VolumeUp\0VolumeDown\0ToggleMute\0"
    "ChangeVolume\0ViewShortcut\0Hwdec"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__ActionFactory[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       1,   46, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       3,    1,   37,    2, 0x06 /* Public */,
       4,    1,   40,    2, 0x06 /* Public */,
       5,    1,   43,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,

 // enums: name, alias, flags, count, data
       6,    6, 0x0,   75,   51,

 // enum data: key, value
       7, uint(dmr::ActionFactory::Invalid),
       8, uint(dmr::ActionFactory::OpenFile),
       9, uint(dmr::ActionFactory::OpenFileList),
      10, uint(dmr::ActionFactory::OpenDirectory),
      11, uint(dmr::ActionFactory::StartPlay),
      12, uint(dmr::ActionFactory::Settings),
      13, uint(dmr::ActionFactory::About),
      14, uint(dmr::ActionFactory::Help),
      15, uint(dmr::ActionFactory::Exit),
      16, uint(dmr::ActionFactory::TogglePlaylist),
      17, uint(dmr::ActionFactory::EmptyPlaylist),
      18, uint(dmr::ActionFactory::PlaylistRemoveItem),
      19, uint(dmr::ActionFactory::PlaylistOpenItemInFM),
      20, uint(dmr::ActionFactory::PlaylistItemInfo),
      21, uint(dmr::ActionFactory::MovieInfo),
      22, uint(dmr::ActionFactory::OpenUrl),
      23, uint(dmr::ActionFactory::OpenCdrom),
      24, uint(dmr::ActionFactory::ToggleFullscreen),
      25, uint(dmr::ActionFactory::QuitFullscreen),
      26, uint(dmr::ActionFactory::ToggleMiniMode),
      27, uint(dmr::ActionFactory::WindowAbove),
      28, uint(dmr::ActionFactory::LoadSubtitle),
      29, uint(dmr::ActionFactory::SelectSubtitle),
      30, uint(dmr::ActionFactory::HideSubtitle),
      31, uint(dmr::ActionFactory::MatchOnlineSubtitle),
      32, uint(dmr::ActionFactory::ChangeSubCodepage),
      33, uint(dmr::ActionFactory::Screenshot),
      34, uint(dmr::ActionFactory::BurstScreenshot),
      35, uint(dmr::ActionFactory::GoToScreenshotSolder),
      36, uint(dmr::ActionFactory::SeekForward),
      37, uint(dmr::ActionFactory::SeekForwardLarge),
      38, uint(dmr::ActionFactory::SeekBackward),
      39, uint(dmr::ActionFactory::SeekBackwardLarge),
      40, uint(dmr::ActionFactory::SeekAbsolute),
      41, uint(dmr::ActionFactory::TogglePause),
      42, uint(dmr::ActionFactory::Stop),
      43, uint(dmr::ActionFactory::AccelPlayback),
      44, uint(dmr::ActionFactory::DecelPlayback),
      45, uint(dmr::ActionFactory::ResetPlayback),
      46, uint(dmr::ActionFactory::SubDelay),
      47, uint(dmr::ActionFactory::SubForward),
      48, uint(dmr::ActionFactory::OrderPlay),
      49, uint(dmr::ActionFactory::ShufflePlay),
      50, uint(dmr::ActionFactory::SinglePlay),
      51, uint(dmr::ActionFactory::SingleLoop),
      52, uint(dmr::ActionFactory::ListLoop),
      53, uint(dmr::ActionFactory::ZeroPointFiveTimes),
      54, uint(dmr::ActionFactory::OneTimes),
      55, uint(dmr::ActionFactory::OnePointTwoTimes),
      56, uint(dmr::ActionFactory::OnePointFiveTimes),
      57, uint(dmr::ActionFactory::Double),
      58, uint(dmr::ActionFactory::DefaultFrame),
      59, uint(dmr::ActionFactory::Ratio4x3Frame),
      60, uint(dmr::ActionFactory::Ratio16x9Frame),
      61, uint(dmr::ActionFactory::Ratio16x10Frame),
      62, uint(dmr::ActionFactory::Ratio185x1Frame),
      63, uint(dmr::ActionFactory::Ratio235x1Frame),
      64, uint(dmr::ActionFactory::ClockwiseFrame),
      65, uint(dmr::ActionFactory::CounterclockwiseFrame),
      66, uint(dmr::ActionFactory::NextFrame),
      67, uint(dmr::ActionFactory::PreviousFrame),
      68, uint(dmr::ActionFactory::Stereo),
      69, uint(dmr::ActionFactory::LeftChannel),
      70, uint(dmr::ActionFactory::RightChannel),
      71, uint(dmr::ActionFactory::LoadTrack),
      72, uint(dmr::ActionFactory::SelectTrack),
      73, uint(dmr::ActionFactory::GotoPlaylistNext),
      74, uint(dmr::ActionFactory::GotoPlaylistPrev),
      75, uint(dmr::ActionFactory::GotoPlaylistSelected),
      76, uint(dmr::ActionFactory::VolumeUp),
      77, uint(dmr::ActionFactory::VolumeDown),
      78, uint(dmr::ActionFactory::ToggleMute),
      79, uint(dmr::ActionFactory::ChangeVolume),
      80, uint(dmr::ActionFactory::ViewShortcut),
      81, uint(dmr::ActionFactory::Hwdec),

       0        // eod
};

void dmr::ActionFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ActionFactory *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->frameMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->playSpeedMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->subtitleMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->soundMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ActionFactory::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ActionFactory::frameMenuEnable)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ActionFactory::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ActionFactory::playSpeedMenuEnable)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (ActionFactory::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ActionFactory::subtitleMenuEnable)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (ActionFactory::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ActionFactory::soundMenuEnable)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::ActionFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dmr__ActionFactory.data,
    qt_meta_data_dmr__ActionFactory,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::ActionFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::ActionFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__ActionFactory.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dmr::ActionFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dmr::ActionFactory::frameMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dmr::ActionFactory::playSpeedMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void dmr::ActionFactory::subtitleMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void dmr::ActionFactory::soundMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
