/****************************************************************************
** Meta object code from reading C++ file 'player_backend.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../player_backend.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'player_backend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__Backend_t {
    QByteArrayData data[56];
    char stringdata0[551];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__Backend_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__Backend_t qt_meta_stringdata_dmr__Backend = {
    {
QT_MOC_LITERAL(0, 0, 12), // "dmr::Backend"
QT_MOC_LITERAL(1, 13, 13), // "tracksChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 14), // "elapsedChanged"
QT_MOC_LITERAL(4, 43, 16), // "videoSizeChanged"
QT_MOC_LITERAL(5, 60, 12), // "stateChanged"
QT_MOC_LITERAL(6, 73, 10), // "fileLoaded"
QT_MOC_LITERAL(7, 84, 11), // "muteChanged"
QT_MOC_LITERAL(8, 96, 13), // "volumeChanged"
QT_MOC_LITERAL(9, 110, 10), // "sidChanged"
QT_MOC_LITERAL(10, 121, 10), // "aidChanged"
QT_MOC_LITERAL(11, 132, 16), // "notifyScreenshot"
QT_MOC_LITERAL(12, 149, 5), // "frame"
QT_MOC_LITERAL(13, 155, 4), // "time"
QT_MOC_LITERAL(14, 160, 19), // "mpvErrorLogsChanged"
QT_MOC_LITERAL(15, 180, 6), // "prefix"
QT_MOC_LITERAL(16, 187, 4), // "text"
QT_MOC_LITERAL(17, 192, 21), // "mpvWarningLogsChanged"
QT_MOC_LITERAL(18, 214, 8), // "urlpause"
QT_MOC_LITERAL(19, 223, 6), // "status"
QT_MOC_LITERAL(20, 230, 13), // "sigMediaError"
QT_MOC_LITERAL(21, 244, 4), // "play"
QT_MOC_LITERAL(22, 249, 11), // "pauseResume"
QT_MOC_LITERAL(23, 261, 4), // "stop"
QT_MOC_LITERAL(24, 266, 11), // "seekForward"
QT_MOC_LITERAL(25, 278, 4), // "secs"
QT_MOC_LITERAL(26, 283, 12), // "seekBackward"
QT_MOC_LITERAL(27, 296, 12), // "seekAbsolute"
QT_MOC_LITERAL(28, 309, 8), // "volumeUp"
QT_MOC_LITERAL(29, 318, 10), // "volumeDown"
QT_MOC_LITERAL(30, 329, 12), // "changeVolume"
QT_MOC_LITERAL(31, 342, 3), // "val"
QT_MOC_LITERAL(32, 346, 10), // "toggleMute"
QT_MOC_LITERAL(33, 357, 7), // "setMute"
QT_MOC_LITERAL(34, 365, 5), // "bMute"
QT_MOC_LITERAL(35, 371, 8), // "duration"
QT_MOC_LITERAL(36, 380, 7), // "elapsed"
QT_MOC_LITERAL(37, 388, 9), // "videoSize"
QT_MOC_LITERAL(38, 398, 6), // "paused"
QT_MOC_LITERAL(39, 405, 5), // "state"
QT_MOC_LITERAL(40, 411, 9), // "PlayState"
QT_MOC_LITERAL(41, 421, 7), // "Playing"
QT_MOC_LITERAL(42, 429, 6), // "Paused"
QT_MOC_LITERAL(43, 436, 7), // "Stopped"
QT_MOC_LITERAL(44, 444, 10), // "DebugLevel"
QT_MOC_LITERAL(45, 455, 4), // "Info"
QT_MOC_LITERAL(46, 460, 5), // "Debug"
QT_MOC_LITERAL(47, 466, 7), // "Verbose"
QT_MOC_LITERAL(48, 474, 9), // "SoundMode"
QT_MOC_LITERAL(49, 484, 6), // "Stereo"
QT_MOC_LITERAL(50, 491, 4), // "Left"
QT_MOC_LITERAL(51, 496, 5), // "Right"
QT_MOC_LITERAL(52, 502, 11), // "hwaccelMode"
QT_MOC_LITERAL(53, 514, 11), // "hwaccelAuto"
QT_MOC_LITERAL(54, 526, 11), // "hwaccelOpen"
QT_MOC_LITERAL(55, 538, 12) // "hwaccelClose"

    },
    "dmr::Backend\0tracksChanged\0\0elapsedChanged\0"
    "videoSizeChanged\0stateChanged\0fileLoaded\0"
    "muteChanged\0volumeChanged\0sidChanged\0"
    "aidChanged\0notifyScreenshot\0frame\0"
    "time\0mpvErrorLogsChanged\0prefix\0text\0"
    "mpvWarningLogsChanged\0urlpause\0status\0"
    "sigMediaError\0play\0pauseResume\0stop\0"
    "seekForward\0secs\0seekBackward\0"
    "seekAbsolute\0volumeUp\0volumeDown\0"
    "changeVolume\0val\0toggleMute\0setMute\0"
    "bMute\0duration\0elapsed\0videoSize\0"
    "paused\0state\0PlayState\0Playing\0Paused\0"
    "Stopped\0DebugLevel\0Info\0Debug\0Verbose\0"
    "SoundMode\0Stereo\0Left\0Right\0hwaccelMode\0"
    "hwaccelAuto\0hwaccelOpen\0hwaccelClose"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__Backend[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      25,   14, // methods
       5,  188, // properties
       4,  208, // enums/sets
       0,    0, // constructors
       0,       // flags
      14,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  139,    2, 0x06 /* Public */,
       3,    0,  140,    2, 0x06 /* Public */,
       4,    0,  141,    2, 0x06 /* Public */,
       5,    0,  142,    2, 0x06 /* Public */,
       6,    0,  143,    2, 0x06 /* Public */,
       7,    0,  144,    2, 0x06 /* Public */,
       8,    0,  145,    2, 0x06 /* Public */,
       9,    0,  146,    2, 0x06 /* Public */,
      10,    0,  147,    2, 0x06 /* Public */,
      11,    2,  148,    2, 0x06 /* Public */,
      14,    2,  153,    2, 0x06 /* Public */,
      17,    2,  158,    2, 0x06 /* Public */,
      18,    1,  163,    2, 0x06 /* Public */,
      20,    0,  166,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      21,    0,  167,    2, 0x0a /* Public */,
      22,    0,  168,    2, 0x0a /* Public */,
      23,    0,  169,    2, 0x0a /* Public */,
      24,    1,  170,    2, 0x0a /* Public */,
      26,    1,  173,    2, 0x0a /* Public */,
      27,    1,  176,    2, 0x0a /* Public */,
      28,    0,  179,    2, 0x0a /* Public */,
      29,    0,  180,    2, 0x0a /* Public */,
      30,    1,  181,    2, 0x0a /* Public */,
      32,    0,  184,    2, 0x0a /* Public */,
      33,    1,  185,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QImage, QMetaType::LongLong,   12,   13,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   15,   16,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   15,   16,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   31,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   34,

 // properties: name, type, flags
      35, QMetaType::LongLong, 0x00095001,
      36, QMetaType::LongLong, 0x00495001,
      37, QMetaType::QSize, 0x00495001,
      38, QMetaType::Bool, 0x00095001,
      39, 0x80000000 | 40, 0x00495009,

 // properties: notify_signal_id
       0,
       1,
       2,
       0,
       3,

 // enums: name, alias, flags, count, data
      40,   40, 0x0,    3,  228,
      44,   44, 0x0,    3,  234,
      48,   48, 0x0,    3,  240,
      52,   52, 0x0,    3,  246,

 // enum data: key, value
      41, uint(dmr::Backend::Playing),
      42, uint(dmr::Backend::Paused),
      43, uint(dmr::Backend::Stopped),
      45, uint(dmr::Backend::Info),
      46, uint(dmr::Backend::Debug),
      47, uint(dmr::Backend::Verbose),
      49, uint(dmr::Backend::Stereo),
      50, uint(dmr::Backend::Left),
      51, uint(dmr::Backend::Right),
      53, uint(dmr::Backend::hwaccelAuto),
      54, uint(dmr::Backend::hwaccelOpen),
      55, uint(dmr::Backend::hwaccelClose),

       0        // eod
};

void dmr::Backend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Backend *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->tracksChanged(); break;
        case 1: _t->elapsedChanged(); break;
        case 2: _t->videoSizeChanged(); break;
        case 3: _t->stateChanged(); break;
        case 4: _t->fileLoaded(); break;
        case 5: _t->muteChanged(); break;
        case 6: _t->volumeChanged(); break;
        case 7: _t->sidChanged(); break;
        case 8: _t->aidChanged(); break;
        case 9: _t->notifyScreenshot((*reinterpret_cast< const QImage(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2]))); break;
        case 10: _t->mpvErrorLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 11: _t->mpvWarningLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 12: _t->urlpause((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->sigMediaError(); break;
        case 14: _t->play(); break;
        case 15: _t->pauseResume(); break;
        case 16: _t->stop(); break;
        case 17: _t->seekForward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->seekBackward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->seekAbsolute((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->volumeUp(); break;
        case 21: _t->volumeDown(); break;
        case 22: _t->changeVolume((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->toggleMute(); break;
        case 24: _t->setMute((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::tracksChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::elapsedChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::videoSizeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::stateChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::fileLoaded)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::muteChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::volumeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::sidChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::aidChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Backend::*)(const QImage & , qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::notifyScreenshot)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Backend::*)(const QString , const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::mpvErrorLogsChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Backend::*)(const QString , const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::mpvWarningLogsChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Backend::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::urlpause)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Backend::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Backend::sigMediaError)) {
                *result = 13;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Backend *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qint64*>(_v) = _t->duration(); break;
        case 1: *reinterpret_cast< qint64*>(_v) = _t->elapsed(); break;
        case 2: *reinterpret_cast< QSize*>(_v) = _t->videoSize(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->paused(); break;
        case 4: *reinterpret_cast< PlayState*>(_v) = _t->state(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject dmr::Backend::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dmr__Backend.data,
    qt_meta_data_dmr__Backend,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::Backend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Backend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__Backend.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::Backend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 25;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void dmr::Backend::tracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::Backend::elapsedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dmr::Backend::videoSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::Backend::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dmr::Backend::fileLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dmr::Backend::muteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dmr::Backend::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dmr::Backend::sidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dmr::Backend::aidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void dmr::Backend::notifyScreenshot(const QImage & _t1, qint64 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void dmr::Backend::mpvErrorLogsChanged(const QString _t1, const QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void dmr::Backend::mpvWarningLogsChanged(const QString _t1, const QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void dmr::Backend::urlpause(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void dmr::Backend::sigMediaError()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
