/****************************************************************************
** Meta object code from reading C++ file 'toolbutton.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../widgets/toolbutton.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'toolbutton.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__ButtonBoxButton_t {
    QByteArrayData data[4];
    char stringdata0[37];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__ButtonBoxButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__ButtonBoxButton_t qt_meta_stringdata_dmr__ButtonBoxButton = {
    {
QT_MOC_LITERAL(0, 0, 20), // "dmr::ButtonBoxButton"
QT_MOC_LITERAL(1, 21, 7), // "entered"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 6) // "leaved"

    },
    "dmr::ButtonBoxButton\0entered\0\0leaved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__ButtonBoxButton[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    0,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void dmr::ButtonBoxButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ButtonBoxButton *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->entered(); break;
        case 1: _t->leaved(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ButtonBoxButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ButtonBoxButton::entered)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ButtonBoxButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ButtonBoxButton::leaved)) {
                *result = 1;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::ButtonBoxButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DButtonBoxButton::staticMetaObject>(),
    qt_meta_stringdata_dmr__ButtonBoxButton.data,
    qt_meta_data_dmr__ButtonBoxButton,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::ButtonBoxButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::ButtonBoxButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__ButtonBoxButton.stringdata0))
        return static_cast<void*>(this);
    return DButtonBoxButton::qt_metacast(_clname);
}

int dmr::ButtonBoxButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DButtonBoxButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dmr::ButtonBoxButton::entered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::ButtonBoxButton::leaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_dmr__ButtonToolTip_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__ButtonToolTip_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__ButtonToolTip_t qt_meta_stringdata_dmr__ButtonToolTip = {
    {
QT_MOC_LITERAL(0, 0, 18) // "dmr::ButtonToolTip"

    },
    "dmr::ButtonToolTip"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__ButtonToolTip[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::ButtonToolTip::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::ButtonToolTip::staticMetaObject = { {
    QMetaObject::SuperData::link<DArrowRectangle::staticMetaObject>(),
    qt_meta_stringdata_dmr__ButtonToolTip.data,
    qt_meta_data_dmr__ButtonToolTip,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::ButtonToolTip::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::ButtonToolTip::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__ButtonToolTip.stringdata0))
        return static_cast<void*>(this);
    return DArrowRectangle::qt_metacast(_clname);
}

int dmr::ButtonToolTip::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DArrowRectangle::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__ToolTip_t {
    QByteArrayData data[4];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__ToolTip_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__ToolTip_t qt_meta_stringdata_dmr__ToolTip = {
    {
QT_MOC_LITERAL(0, 0, 12), // "dmr::ToolTip"
QT_MOC_LITERAL(1, 13, 13), // "slotWMChanged"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 3) // "msg"

    },
    "dmr::ToolTip\0slotWMChanged\0\0msg"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__ToolTip[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void dmr::ToolTip::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ToolTip *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotWMChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::ToolTip::staticMetaObject = { {
    QMetaObject::SuperData::link<QFrame::staticMetaObject>(),
    qt_meta_stringdata_dmr__ToolTip.data,
    qt_meta_data_dmr__ToolTip,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::ToolTip::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::ToolTip::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__ToolTip.stringdata0))
        return static_cast<void*>(this);
    return QFrame::qt_metacast(_clname);
}

int dmr::ToolTip::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFrame::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_dmr__ToolButton_t {
    QByteArrayData data[4];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__ToolButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__ToolButton_t qt_meta_stringdata_dmr__ToolButton = {
    {
QT_MOC_LITERAL(0, 0, 15), // "dmr::ToolButton"
QT_MOC_LITERAL(1, 16, 7), // "entered"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 6) // "leaved"

    },
    "dmr::ToolButton\0entered\0\0leaved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__ToolButton[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    0,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void dmr::ToolButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ToolButton *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->entered(); break;
        case 1: _t->leaved(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ToolButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ToolButton::entered)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ToolButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ToolButton::leaved)) {
                *result = 1;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::ToolButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DIconButton::staticMetaObject>(),
    qt_meta_stringdata_dmr__ToolButton.data,
    qt_meta_data_dmr__ToolButton,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::ToolButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::ToolButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__ToolButton.stringdata0))
        return static_cast<void*>(this);
    return DIconButton::qt_metacast(_clname);
}

int dmr::ToolButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DIconButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dmr::ToolButton::entered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::ToolButton::leaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_dmr__VolumeButton_t {
    QByteArrayData data[7];
    char stringdata0[83];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__VolumeButton_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__VolumeButton_t qt_meta_stringdata_dmr__VolumeButton = {
    {
QT_MOC_LITERAL(0, 0, 17), // "dmr::VolumeButton"
QT_MOC_LITERAL(1, 18, 7), // "entered"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 6), // "leaved"
QT_MOC_LITERAL(4, 34, 15), // "requestVolumeUp"
QT_MOC_LITERAL(5, 50, 17), // "requestVolumeDown"
QT_MOC_LITERAL(6, 68, 14) // "sigUnsupported"

    },
    "dmr::VolumeButton\0entered\0\0leaved\0"
    "requestVolumeUp\0requestVolumeDown\0"
    "sigUnsupported"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__VolumeButton[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    0,   40,    2, 0x06 /* Public */,
       4,    0,   41,    2, 0x06 /* Public */,
       5,    0,   42,    2, 0x06 /* Public */,
       6,    0,   43,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void dmr::VolumeButton::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<VolumeButton *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->entered(); break;
        case 1: _t->leaved(); break;
        case 2: _t->requestVolumeUp(); break;
        case 3: _t->requestVolumeDown(); break;
        case 4: _t->sigUnsupported(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (VolumeButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VolumeButton::entered)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (VolumeButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VolumeButton::leaved)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (VolumeButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VolumeButton::requestVolumeUp)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (VolumeButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VolumeButton::requestVolumeDown)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (VolumeButton::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&VolumeButton::sigUnsupported)) {
                *result = 4;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::VolumeButton::staticMetaObject = { {
    QMetaObject::SuperData::link<DIconButton::staticMetaObject>(),
    qt_meta_stringdata_dmr__VolumeButton.data,
    qt_meta_data_dmr__VolumeButton,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::VolumeButton::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::VolumeButton::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__VolumeButton.stringdata0))
        return static_cast<void*>(this);
    return DIconButton::qt_metacast(_clname);
}

int dmr::VolumeButton::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DIconButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dmr::VolumeButton::entered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::VolumeButton::leaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dmr::VolumeButton::requestVolumeUp()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::VolumeButton::requestVolumeDown()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dmr::VolumeButton::sigUnsupported()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
