/****************************************************************************
** Meta object code from reading C++ file 'online_sub.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../libdmr/online_sub.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'online_sub.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__OnlineSubtitle_t {
    QByteArrayData data[14];
    char stringdata0[183];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__OnlineSubtitle_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__OnlineSubtitle_t qt_meta_stringdata_dmr__OnlineSubtitle = {
    {
QT_MOC_LITERAL(0, 0, 19), // "dmr::OnlineSubtitle"
QT_MOC_LITERAL(1, 20, 22), // "subtitlesDownloadedFor"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 3), // "url"
QT_MOC_LITERAL(4, 48, 14), // "QList<QString>"
QT_MOC_LITERAL(5, 63, 9), // "filenames"
QT_MOC_LITERAL(6, 73, 10), // "FailReason"
QT_MOC_LITERAL(7, 84, 1), // "r"
QT_MOC_LITERAL(8, 86, 26), // "onlineSubtitleStateChanged"
QT_MOC_LITERAL(9, 113, 6), // "reason"
QT_MOC_LITERAL(10, 120, 15), // "requestSubtitle"
QT_MOC_LITERAL(11, 136, 13), // "replyReceived"
QT_MOC_LITERAL(12, 150, 14), // "QNetworkReply*"
QT_MOC_LITERAL(13, 165, 17) // "downloadSubtitles"

    },
    "dmr::OnlineSubtitle\0subtitlesDownloadedFor\0"
    "\0url\0QList<QString>\0filenames\0FailReason\0"
    "r\0onlineSubtitleStateChanged\0reason\0"
    "requestSubtitle\0replyReceived\0"
    "QNetworkReply*\0downloadSubtitles"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__OnlineSubtitle[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   39,    2, 0x06 /* Public */,
       8,    1,   46,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,   49,    2, 0x0a /* Public */,
      11,    1,   52,    2, 0x08 /* Private */,
      13,    0,   55,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl, 0x80000000 | 4, 0x80000000 | 6,    3,    5,    7,
    QMetaType::Void, 0x80000000 | 6,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void,

       0        // eod
};

void dmr::OnlineSubtitle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<OnlineSubtitle *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->subtitlesDownloadedFor((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QList<QString>(*)>(_a[2])),(*reinterpret_cast< FailReason(*)>(_a[3]))); break;
        case 1: _t->onlineSubtitleStateChanged((*reinterpret_cast< const FailReason(*)>(_a[1]))); break;
        case 2: _t->requestSubtitle((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 3: _t->replyReceived((*reinterpret_cast< QNetworkReply*(*)>(_a[1]))); break;
        case 4: _t->downloadSubtitles(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QString> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QNetworkReply* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (OnlineSubtitle::*)(const QUrl & , const QList<QString> & , FailReason );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OnlineSubtitle::subtitlesDownloadedFor)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (OnlineSubtitle::*)(const FailReason );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&OnlineSubtitle::onlineSubtitleStateChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::OnlineSubtitle::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dmr__OnlineSubtitle.data,
    qt_meta_data_dmr__OnlineSubtitle,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::OnlineSubtitle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::OnlineSubtitle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__OnlineSubtitle.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dmr::OnlineSubtitle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dmr::OnlineSubtitle::subtitlesDownloadedFor(const QUrl & _t1, const QList<QString> & _t2, FailReason _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dmr::OnlineSubtitle::onlineSubtitleStateChanged(const FailReason _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
