/****************************************************************************
** Meta object code from reading C++ file 'player_engine.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../libdmr/player_engine.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'player_engine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__PlayerEngine_t {
    QByteArrayData data[74];
    char stringdata0[888];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__PlayerEngine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__PlayerEngine_t qt_meta_stringdata_dmr__PlayerEngine = {
    {
QT_MOC_LITERAL(0, 0, 17), // "dmr::PlayerEngine"
QT_MOC_LITERAL(1, 18, 13), // "tracksChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 14), // "elapsedChanged"
QT_MOC_LITERAL(4, 48, 16), // "videoSizeChanged"
QT_MOC_LITERAL(5, 65, 12), // "stateChanged"
QT_MOC_LITERAL(6, 78, 10), // "fileLoaded"
QT_MOC_LITERAL(7, 89, 11), // "muteChanged"
QT_MOC_LITERAL(8, 101, 13), // "volumeChanged"
QT_MOC_LITERAL(9, 115, 10), // "sidChanged"
QT_MOC_LITERAL(10, 126, 10), // "aidChanged"
QT_MOC_LITERAL(11, 137, 18), // "subCodepageChanged"
QT_MOC_LITERAL(12, 156, 27), // "loadOnlineSubtitlesFinished"
QT_MOC_LITERAL(13, 184, 3), // "url"
QT_MOC_LITERAL(14, 188, 7), // "success"
QT_MOC_LITERAL(15, 196, 15), // "mpvFunsLoadOver"
QT_MOC_LITERAL(16, 212, 16), // "notifyScreenshot"
QT_MOC_LITERAL(17, 229, 5), // "frame"
QT_MOC_LITERAL(18, 235, 4), // "time"
QT_MOC_LITERAL(19, 240, 15), // "playlistChanged"
QT_MOC_LITERAL(20, 256, 18), // "onlineStateChanged"
QT_MOC_LITERAL(21, 275, 8), // "isOnline"
QT_MOC_LITERAL(22, 284, 19), // "mpvErrorLogsChanged"
QT_MOC_LITERAL(23, 304, 6), // "prefix"
QT_MOC_LITERAL(24, 311, 4), // "text"
QT_MOC_LITERAL(25, 316, 21), // "mpvWarningLogsChanged"
QT_MOC_LITERAL(26, 338, 8), // "urlpause"
QT_MOC_LITERAL(27, 347, 6), // "status"
QT_MOC_LITERAL(28, 354, 22), // "siginitthumbnailseting"
QT_MOC_LITERAL(29, 377, 14), // "updateDuration"
QT_MOC_LITERAL(30, 392, 14), // "sigInvalidFile"
QT_MOC_LITERAL(31, 407, 11), // "strFileName"
QT_MOC_LITERAL(32, 419, 13), // "sigMediaError"
QT_MOC_LITERAL(33, 433, 16), // "finishedAddFiles"
QT_MOC_LITERAL(34, 450, 11), // "QList<QUrl>"
QT_MOC_LITERAL(35, 462, 4), // "play"
QT_MOC_LITERAL(36, 467, 11), // "pauseResume"
QT_MOC_LITERAL(37, 479, 4), // "stop"
QT_MOC_LITERAL(38, 484, 4), // "prev"
QT_MOC_LITERAL(39, 489, 4), // "next"
QT_MOC_LITERAL(40, 494, 12), // "playSelected"
QT_MOC_LITERAL(41, 507, 2), // "id"
QT_MOC_LITERAL(42, 510, 10), // "playByName"
QT_MOC_LITERAL(43, 521, 13), // "clearPlaylist"
QT_MOC_LITERAL(44, 535, 11), // "seekForward"
QT_MOC_LITERAL(45, 547, 4), // "secs"
QT_MOC_LITERAL(46, 552, 12), // "seekBackward"
QT_MOC_LITERAL(47, 565, 12), // "seekAbsolute"
QT_MOC_LITERAL(48, 578, 3), // "pos"
QT_MOC_LITERAL(49, 582, 8), // "volumeUp"
QT_MOC_LITERAL(50, 591, 10), // "volumeDown"
QT_MOC_LITERAL(51, 602, 12), // "changeVolume"
QT_MOC_LITERAL(52, 615, 3), // "val"
QT_MOC_LITERAL(53, 619, 10), // "toggleMute"
QT_MOC_LITERAL(54, 630, 7), // "setMute"
QT_MOC_LITERAL(55, 638, 5), // "bMute"
QT_MOC_LITERAL(56, 644, 21), // "onBackendStateChanged"
QT_MOC_LITERAL(57, 666, 11), // "requestPlay"
QT_MOC_LITERAL(58, 678, 15), // "updateSubStyles"
QT_MOC_LITERAL(59, 694, 21), // "onSubtitlesDownloaded"
QT_MOC_LITERAL(60, 716, 14), // "QList<QString>"
QT_MOC_LITERAL(61, 731, 9), // "filenames"
QT_MOC_LITERAL(62, 741, 26), // "OnlineSubtitle::FailReason"
QT_MOC_LITERAL(63, 768, 29), // "onPlaylistAsyncAppendFinished"
QT_MOC_LITERAL(64, 798, 19), // "QList<PlayItemInfo>"
QT_MOC_LITERAL(65, 818, 8), // "duration"
QT_MOC_LITERAL(66, 827, 7), // "elapsed"
QT_MOC_LITERAL(67, 835, 9), // "videoSize"
QT_MOC_LITERAL(68, 845, 6), // "paused"
QT_MOC_LITERAL(69, 852, 5), // "state"
QT_MOC_LITERAL(70, 858, 9), // "CoreState"
QT_MOC_LITERAL(71, 868, 4), // "Idle"
QT_MOC_LITERAL(72, 873, 7), // "Playing"
QT_MOC_LITERAL(73, 881, 6) // "Paused"

    },
    "dmr::PlayerEngine\0tracksChanged\0\0"
    "elapsedChanged\0videoSizeChanged\0"
    "stateChanged\0fileLoaded\0muteChanged\0"
    "volumeChanged\0sidChanged\0aidChanged\0"
    "subCodepageChanged\0loadOnlineSubtitlesFinished\0"
    "url\0success\0mpvFunsLoadOver\0"
    "notifyScreenshot\0frame\0time\0playlistChanged\0"
    "onlineStateChanged\0isOnline\0"
    "mpvErrorLogsChanged\0prefix\0text\0"
    "mpvWarningLogsChanged\0urlpause\0status\0"
    "siginitthumbnailseting\0updateDuration\0"
    "sigInvalidFile\0strFileName\0sigMediaError\0"
    "finishedAddFiles\0QList<QUrl>\0play\0"
    "pauseResume\0stop\0prev\0next\0playSelected\0"
    "id\0playByName\0clearPlaylist\0seekForward\0"
    "secs\0seekBackward\0seekAbsolute\0pos\0"
    "volumeUp\0volumeDown\0changeVolume\0val\0"
    "toggleMute\0setMute\0bMute\0onBackendStateChanged\0"
    "requestPlay\0updateSubStyles\0"
    "onSubtitlesDownloaded\0QList<QString>\0"
    "filenames\0OnlineSubtitle::FailReason\0"
    "onPlaylistAsyncAppendFinished\0"
    "QList<PlayItemInfo>\0duration\0elapsed\0"
    "videoSize\0paused\0state\0CoreState\0Idle\0"
    "Playing\0Paused"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__PlayerEngine[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      44,   14, // methods
       5,  326, // properties
       1,  346, // enums/sets
       0,    0, // constructors
       0,       // flags
      23,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  234,    2, 0x06 /* Public */,
       3,    0,  235,    2, 0x06 /* Public */,
       4,    0,  236,    2, 0x06 /* Public */,
       5,    0,  237,    2, 0x06 /* Public */,
       6,    0,  238,    2, 0x06 /* Public */,
       7,    0,  239,    2, 0x06 /* Public */,
       8,    0,  240,    2, 0x06 /* Public */,
       9,    0,  241,    2, 0x06 /* Public */,
      10,    0,  242,    2, 0x06 /* Public */,
      11,    0,  243,    2, 0x06 /* Public */,
      12,    2,  244,    2, 0x06 /* Public */,
      15,    0,  249,    2, 0x06 /* Public */,
      16,    2,  250,    2, 0x06 /* Public */,
      19,    0,  255,    2, 0x06 /* Public */,
      20,    1,  256,    2, 0x06 /* Public */,
      22,    2,  259,    2, 0x06 /* Public */,
      25,    2,  264,    2, 0x06 /* Public */,
      26,    1,  269,    2, 0x06 /* Public */,
      28,    0,  272,    2, 0x06 /* Public */,
      29,    0,  273,    2, 0x06 /* Public */,
      30,    1,  274,    2, 0x06 /* Public */,
      32,    0,  277,    2, 0x06 /* Public */,
      33,    1,  278,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      35,    0,  281,    2, 0x0a /* Public */,
      36,    0,  282,    2, 0x0a /* Public */,
      37,    0,  283,    2, 0x0a /* Public */,
      38,    0,  284,    2, 0x0a /* Public */,
      39,    0,  285,    2, 0x0a /* Public */,
      40,    1,  286,    2, 0x0a /* Public */,
      42,    1,  289,    2, 0x0a /* Public */,
      43,    0,  292,    2, 0x0a /* Public */,
      44,    1,  293,    2, 0x0a /* Public */,
      46,    1,  296,    2, 0x0a /* Public */,
      47,    1,  299,    2, 0x0a /* Public */,
      49,    0,  302,    2, 0x0a /* Public */,
      50,    0,  303,    2, 0x0a /* Public */,
      51,    1,  304,    2, 0x0a /* Public */,
      53,    0,  307,    2, 0x0a /* Public */,
      54,    1,  308,    2, 0x0a /* Public */,
      56,    0,  311,    2, 0x09 /* Protected */,
      57,    1,  312,    2, 0x09 /* Protected */,
      58,    0,  315,    2, 0x09 /* Protected */,
      59,    3,  316,    2, 0x09 /* Protected */,
      63,    1,  323,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::Bool,   13,   14,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QImage, QMetaType::LongLong,   17,   18,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   21,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   23,   24,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   23,   24,
    QMetaType::Void, QMetaType::Bool,   27,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   31,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 34,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   41,
    QMetaType::Void, QMetaType::QUrl,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   45,
    QMetaType::Void, QMetaType::Int,   45,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   52,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   55,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   41,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, 0x80000000 | 60, 0x80000000 | 62,   13,   61,    2,
    QMetaType::Void, 0x80000000 | 64,    2,

 // properties: name, type, flags
      65, QMetaType::LongLong, 0x00095001,
      66, QMetaType::LongLong, 0x00495001,
      67, QMetaType::QSize, 0x00495001,
      68, QMetaType::Bool, 0x00095001,
      69, 0x80000000 | 70, 0x00495009,

 // properties: notify_signal_id
       0,
       1,
       2,
       0,
       3,

 // enums: name, alias, flags, count, data
      70,   70, 0x0,    3,  351,

 // enum data: key, value
      71, uint(dmr::PlayerEngine::Idle),
      72, uint(dmr::PlayerEngine::Playing),
      73, uint(dmr::PlayerEngine::Paused),

       0        // eod
};

void dmr::PlayerEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PlayerEngine *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->tracksChanged(); break;
        case 1: _t->elapsedChanged(); break;
        case 2: _t->videoSizeChanged(); break;
        case 3: _t->stateChanged(); break;
        case 4: _t->fileLoaded(); break;
        case 5: _t->muteChanged(); break;
        case 6: _t->volumeChanged(); break;
        case 7: _t->sidChanged(); break;
        case 8: _t->aidChanged(); break;
        case 9: _t->subCodepageChanged(); break;
        case 10: _t->loadOnlineSubtitlesFinished((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 11: _t->mpvFunsLoadOver(); break;
        case 12: _t->notifyScreenshot((*reinterpret_cast< const QImage(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2]))); break;
        case 13: _t->playlistChanged(); break;
        case 14: _t->onlineStateChanged((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 15: _t->mpvErrorLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->mpvWarningLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 17: _t->urlpause((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->siginitthumbnailseting(); break;
        case 19: _t->updateDuration(); break;
        case 20: _t->sigInvalidFile((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 21: _t->sigMediaError(); break;
        case 22: _t->finishedAddFiles((*reinterpret_cast< QList<QUrl>(*)>(_a[1]))); break;
        case 23: _t->play(); break;
        case 24: _t->pauseResume(); break;
        case 25: _t->stop(); break;
        case 26: _t->prev(); break;
        case 27: _t->next(); break;
        case 28: _t->playSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->playByName((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 30: _t->clearPlaylist(); break;
        case 31: _t->seekForward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->seekBackward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->seekAbsolute((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->volumeUp(); break;
        case 35: _t->volumeDown(); break;
        case 36: _t->changeVolume((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: _t->toggleMute(); break;
        case 38: _t->setMute((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->onBackendStateChanged(); break;
        case 40: _t->requestPlay((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 41: _t->updateSubStyles(); break;
        case 42: _t->onSubtitlesDownloaded((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QList<QString>(*)>(_a[2])),(*reinterpret_cast< OnlineSubtitle::FailReason(*)>(_a[3]))); break;
        case 43: _t->onPlaylistAsyncAppendFinished((*reinterpret_cast< const QList<PlayItemInfo>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QString> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::tracksChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::elapsedChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::videoSizeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::stateChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::fileLoaded)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::muteChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::volumeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::sidChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::aidChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::subCodepageChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(const QUrl & , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::loadOnlineSubtitlesFinished)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::mpvFunsLoadOver)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(const QImage & , qint64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::notifyScreenshot)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::playlistChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(const bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::onlineStateChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(const QString , const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::mpvErrorLogsChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(const QString , const QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::mpvWarningLogsChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::urlpause)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::siginitthumbnailseting)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::updateDuration)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::sigInvalidFile)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::sigMediaError)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (PlayerEngine::*)(QList<QUrl> );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PlayerEngine::finishedAddFiles)) {
                *result = 22;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<PlayerEngine *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qint64*>(_v) = _t->duration(); break;
        case 1: *reinterpret_cast< qint64*>(_v) = _t->elapsed(); break;
        case 2: *reinterpret_cast< QSize*>(_v) = _t->videoSize(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->paused(); break;
        case 4: *reinterpret_cast< CoreState*>(_v) = _t->state(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject dmr::PlayerEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dmr__PlayerEngine.data,
    qt_meta_data_dmr__PlayerEngine,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::PlayerEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::PlayerEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__PlayerEngine.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::PlayerEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 5;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 5;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void dmr::PlayerEngine::tracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::PlayerEngine::elapsedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dmr::PlayerEngine::videoSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::PlayerEngine::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dmr::PlayerEngine::fileLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dmr::PlayerEngine::muteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dmr::PlayerEngine::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void dmr::PlayerEngine::sidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void dmr::PlayerEngine::aidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void dmr::PlayerEngine::subCodepageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void dmr::PlayerEngine::loadOnlineSubtitlesFinished(const QUrl & _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void dmr::PlayerEngine::mpvFunsLoadOver()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void dmr::PlayerEngine::notifyScreenshot(const QImage & _t1, qint64 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void dmr::PlayerEngine::playlistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void dmr::PlayerEngine::onlineStateChanged(const bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void dmr::PlayerEngine::mpvErrorLogsChanged(const QString _t1, const QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void dmr::PlayerEngine::mpvWarningLogsChanged(const QString _t1, const QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void dmr::PlayerEngine::urlpause(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void dmr::PlayerEngine::siginitthumbnailseting()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void dmr::PlayerEngine::updateDuration()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void dmr::PlayerEngine::sigInvalidFile(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void dmr::PlayerEngine::sigMediaError()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void dmr::PlayerEngine::finishedAddFiles(QList<QUrl> _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
