/****************************************************************************
** Meta object code from reading C++ file 'qtplayer_proxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../backends/mediaplayer/qtplayer_proxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qtplayer_proxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__QtPlayerProxy_t {
    QByteArrayData data[72];
    char stringdata0[798];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__QtPlayerProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__QtPlayerProxy_t qt_meta_stringdata_dmr__QtPlayerProxy = {
    {
QT_MOC_LITERAL(0, 0, 18), // "dmr::QtPlayerProxy"
QT_MOC_LITERAL(1, 19, 4), // "play"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 11), // "pauseResume"
QT_MOC_LITERAL(4, 37, 4), // "stop"
QT_MOC_LITERAL(5, 42, 11), // "seekForward"
QT_MOC_LITERAL(6, 54, 5), // "nSecs"
QT_MOC_LITERAL(7, 60, 12), // "seekBackward"
QT_MOC_LITERAL(8, 73, 12), // "seekAbsolute"
QT_MOC_LITERAL(9, 86, 4), // "nPos"
QT_MOC_LITERAL(10, 91, 8), // "volumeUp"
QT_MOC_LITERAL(11, 100, 10), // "volumeDown"
QT_MOC_LITERAL(12, 111, 12), // "changeVolume"
QT_MOC_LITERAL(13, 124, 4), // "nVol"
QT_MOC_LITERAL(14, 129, 6), // "volume"
QT_MOC_LITERAL(15, 136, 5), // "muted"
QT_MOC_LITERAL(16, 142, 10), // "toggleMute"
QT_MOC_LITERAL(17, 153, 7), // "setMute"
QT_MOC_LITERAL(18, 161, 5), // "bMute"
QT_MOC_LITERAL(19, 167, 14), // "updateSubStyle"
QT_MOC_LITERAL(20, 182, 4), // "font"
QT_MOC_LITERAL(21, 187, 2), // "sz"
QT_MOC_LITERAL(22, 190, 14), // "setSubCodepage"
QT_MOC_LITERAL(23, 205, 2), // "cp"
QT_MOC_LITERAL(24, 208, 11), // "subCodepage"
QT_MOC_LITERAL(25, 220, 16), // "addSubSearchPath"
QT_MOC_LITERAL(26, 237, 4), // "path"
QT_MOC_LITERAL(27, 242, 12), // "loadSubtitle"
QT_MOC_LITERAL(28, 255, 9), // "QFileInfo"
QT_MOC_LITERAL(29, 265, 2), // "fi"
QT_MOC_LITERAL(30, 268, 14), // "toggleSubtitle"
QT_MOC_LITERAL(31, 283, 12), // "isSubVisible"
QT_MOC_LITERAL(32, 296, 14), // "selectSubtitle"
QT_MOC_LITERAL(33, 311, 2), // "id"
QT_MOC_LITERAL(34, 314, 11), // "selectTrack"
QT_MOC_LITERAL(35, 326, 11), // "setSubDelay"
QT_MOC_LITERAL(36, 338, 4), // "secs"
QT_MOC_LITERAL(37, 343, 8), // "subDelay"
QT_MOC_LITERAL(38, 352, 3), // "aid"
QT_MOC_LITERAL(39, 356, 3), // "sid"
QT_MOC_LITERAL(40, 360, 15), // "changeSoundMode"
QT_MOC_LITERAL(41, 376, 9), // "SoundMode"
QT_MOC_LITERAL(42, 386, 14), // "setVideoAspect"
QT_MOC_LITERAL(43, 401, 1), // "r"
QT_MOC_LITERAL(44, 403, 11), // "videoAspect"
QT_MOC_LITERAL(45, 415, 13), // "videoRotation"
QT_MOC_LITERAL(46, 429, 16), // "setVideoRotation"
QT_MOC_LITERAL(47, 446, 6), // "degree"
QT_MOC_LITERAL(48, 453, 14), // "takeScreenshot"
QT_MOC_LITERAL(49, 468, 15), // "burstScreenshot"
QT_MOC_LITERAL(50, 484, 19), // "stopBurstScreenshot"
QT_MOC_LITERAL(51, 504, 11), // "getProperty"
QT_MOC_LITERAL(52, 516, 11), // "setProperty"
QT_MOC_LITERAL(53, 528, 9), // "nextFrame"
QT_MOC_LITERAL(54, 538, 13), // "previousFrame"
QT_MOC_LITERAL(55, 552, 11), // "makeCurrent"
QT_MOC_LITERAL(56, 564, 17), // "changehwaccelMode"
QT_MOC_LITERAL(57, 582, 11), // "hwaccelMode"
QT_MOC_LITERAL(58, 594, 16), // "slotStateChanged"
QT_MOC_LITERAL(59, 611, 19), // "QMediaPlayer::State"
QT_MOC_LITERAL(60, 631, 8), // "newState"
QT_MOC_LITERAL(61, 640, 22), // "slotMediaStatusChanged"
QT_MOC_LITERAL(62, 663, 25), // "QMediaPlayer::MediaStatus"
QT_MOC_LITERAL(63, 689, 6), // "status"
QT_MOC_LITERAL(64, 696, 19), // "slotPositionChanged"
QT_MOC_LITERAL(65, 716, 8), // "position"
QT_MOC_LITERAL(66, 725, 14), // "slotMediaError"
QT_MOC_LITERAL(67, 740, 19), // "QMediaPlayer::Error"
QT_MOC_LITERAL(68, 760, 5), // "error"
QT_MOC_LITERAL(69, 766, 12), // "processFrame"
QT_MOC_LITERAL(70, 779, 12), // "QVideoFrame&"
QT_MOC_LITERAL(71, 792, 5) // "frame"

    },
    "dmr::QtPlayerProxy\0play\0\0pauseResume\0"
    "stop\0seekForward\0nSecs\0seekBackward\0"
    "seekAbsolute\0nPos\0volumeUp\0volumeDown\0"
    "changeVolume\0nVol\0volume\0muted\0"
    "toggleMute\0setMute\0bMute\0updateSubStyle\0"
    "font\0sz\0setSubCodepage\0cp\0subCodepage\0"
    "addSubSearchPath\0path\0loadSubtitle\0"
    "QFileInfo\0fi\0toggleSubtitle\0isSubVisible\0"
    "selectSubtitle\0id\0selectTrack\0setSubDelay\0"
    "secs\0subDelay\0aid\0sid\0changeSoundMode\0"
    "SoundMode\0setVideoAspect\0r\0videoAspect\0"
    "videoRotation\0setVideoRotation\0degree\0"
    "takeScreenshot\0burstScreenshot\0"
    "stopBurstScreenshot\0getProperty\0"
    "setProperty\0nextFrame\0previousFrame\0"
    "makeCurrent\0changehwaccelMode\0hwaccelMode\0"
    "slotStateChanged\0QMediaPlayer::State\0"
    "newState\0slotMediaStatusChanged\0"
    "QMediaPlayer::MediaStatus\0status\0"
    "slotPositionChanged\0position\0"
    "slotMediaError\0QMediaPlayer::Error\0"
    "error\0processFrame\0QVideoFrame&\0frame"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__QtPlayerProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      45,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  239,    2, 0x0a /* Public */,
       3,    0,  240,    2, 0x0a /* Public */,
       4,    0,  241,    2, 0x0a /* Public */,
       5,    1,  242,    2, 0x0a /* Public */,
       7,    1,  245,    2, 0x0a /* Public */,
       8,    1,  248,    2, 0x0a /* Public */,
      10,    0,  251,    2, 0x0a /* Public */,
      11,    0,  252,    2, 0x0a /* Public */,
      12,    1,  253,    2, 0x0a /* Public */,
      14,    0,  256,    2, 0x0a /* Public */,
      15,    0,  257,    2, 0x0a /* Public */,
      16,    0,  258,    2, 0x0a /* Public */,
      17,    1,  259,    2, 0x0a /* Public */,
      19,    2,  262,    2, 0x0a /* Public */,
      22,    1,  267,    2, 0x0a /* Public */,
      24,    0,  270,    2, 0x0a /* Public */,
      25,    1,  271,    2, 0x0a /* Public */,
      27,    1,  274,    2, 0x0a /* Public */,
      30,    0,  277,    2, 0x0a /* Public */,
      31,    0,  278,    2, 0x0a /* Public */,
      32,    1,  279,    2, 0x0a /* Public */,
      34,    1,  282,    2, 0x0a /* Public */,
      35,    1,  285,    2, 0x0a /* Public */,
      37,    0,  288,    2, 0x0a /* Public */,
      38,    0,  289,    2, 0x0a /* Public */,
      39,    0,  290,    2, 0x0a /* Public */,
      40,    1,  291,    2, 0x0a /* Public */,
      42,    1,  294,    2, 0x0a /* Public */,
      44,    0,  297,    2, 0x0a /* Public */,
      45,    0,  298,    2, 0x0a /* Public */,
      46,    1,  299,    2, 0x0a /* Public */,
      48,    0,  302,    2, 0x0a /* Public */,
      49,    0,  303,    2, 0x0a /* Public */,
      50,    0,  304,    2, 0x0a /* Public */,
      51,    1,  305,    2, 0x0a /* Public */,
      52,    2,  308,    2, 0x0a /* Public */,
      53,    0,  313,    2, 0x0a /* Public */,
      54,    0,  314,    2, 0x0a /* Public */,
      55,    0,  315,    2, 0x0a /* Public */,
      56,    1,  316,    2, 0x0a /* Public */,
      58,    1,  319,    2, 0x09 /* Protected */,
      61,    1,  322,    2, 0x09 /* Protected */,
      64,    1,  325,    2, 0x09 /* Protected */,
      66,    1,  328,    2, 0x09 /* Protected */,
      69,    1,  331,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Int,
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   20,   21,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::QString,
    QMetaType::Void, QMetaType::QString,   26,
    QMetaType::Bool, 0x80000000 | 28,   29,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Int,   33,
    QMetaType::Void, QMetaType::Int,   33,
    QMetaType::Void, QMetaType::Double,   36,
    QMetaType::Double,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Void, 0x80000000 | 41,    2,
    QMetaType::Void, QMetaType::Double,   43,
    QMetaType::Double,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,   47,
    QMetaType::QImage,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::QVariant, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 57,   57,
    QMetaType::Void, 0x80000000 | 59,   60,
    QMetaType::Void, 0x80000000 | 62,   63,
    QMetaType::Void, QMetaType::LongLong,   65,
    QMetaType::Void, 0x80000000 | 67,   68,
    QMetaType::Void, 0x80000000 | 70,   71,

       0        // eod
};

void dmr::QtPlayerProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QtPlayerProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->play(); break;
        case 1: _t->pauseResume(); break;
        case 2: _t->stop(); break;
        case 3: _t->seekForward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->seekBackward((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->seekAbsolute((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->volumeUp(); break;
        case 7: _t->volumeDown(); break;
        case 8: _t->changeVolume((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: { int _r = _t->volume();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->muted();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->toggleMute(); break;
        case 12: _t->setMute((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->updateSubStyle((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 14: _t->setSubCodepage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 15: { QString _r = _t->subCodepage();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->addSubSearchPath((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: { bool _r = _t->loadSubtitle((*reinterpret_cast< const QFileInfo(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->toggleSubtitle(); break;
        case 19: { bool _r = _t->isSubVisible();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->selectSubtitle((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->selectTrack((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->setSubDelay((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 23: { double _r = _t->subDelay();
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->aid();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 25: { int _r = _t->sid();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->changeSoundMode((*reinterpret_cast< SoundMode(*)>(_a[1]))); break;
        case 27: _t->setVideoAspect((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 28: { double _r = _t->videoAspect();
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = std::move(_r); }  break;
        case 29: { int _r = _t->videoRotation();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->setVideoRotation((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 31: { QImage _r = _t->takeScreenshot();
            if (_a[0]) *reinterpret_cast< QImage*>(_a[0]) = std::move(_r); }  break;
        case 32: _t->burstScreenshot(); break;
        case 33: _t->stopBurstScreenshot(); break;
        case 34: { QVariant _r = _t->getProperty((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariant*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->setProperty((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 36: _t->nextFrame(); break;
        case 37: _t->previousFrame(); break;
        case 38: _t->makeCurrent(); break;
        case 39: _t->changehwaccelMode((*reinterpret_cast< hwaccelMode(*)>(_a[1]))); break;
        case 40: _t->slotStateChanged((*reinterpret_cast< QMediaPlayer::State(*)>(_a[1]))); break;
        case 41: _t->slotMediaStatusChanged((*reinterpret_cast< QMediaPlayer::MediaStatus(*)>(_a[1]))); break;
        case 42: _t->slotPositionChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 43: _t->slotMediaError((*reinterpret_cast< QMediaPlayer::Error(*)>(_a[1]))); break;
        case 44: _t->processFrame((*reinterpret_cast< QVideoFrame(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QFileInfo >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaPlayer::State >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaPlayer::MediaStatus >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaPlayer::Error >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::QtPlayerProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<Backend::staticMetaObject>(),
    qt_meta_stringdata_dmr__QtPlayerProxy.data,
    qt_meta_data_dmr__QtPlayerProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::QtPlayerProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::QtPlayerProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__QtPlayerProxy.stringdata0))
        return static_cast<void*>(this);
    return Backend::qt_metacast(_clname);
}

int dmr::QtPlayerProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Backend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
