/****************************************************************************
** Meta object code from reading C++ file 'mircastwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../widgets/mircastwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mircastwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ItemWidget_t {
    QByteArrayData data[4];
    char stringdata0[32];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ItemWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ItemWidget_t qt_meta_stringdata_ItemWidget = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ItemWidget"
QT_MOC_LITERAL(1, 11, 8), // "selected"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 10) // "connecting"

    },
    "ItemWidget\0selected\0\0connecting"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ItemWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    0,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ItemWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ItemWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->selected(); break;
        case 1: _t->connecting(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ItemWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ItemWidget::selected)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (ItemWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ItemWidget::connecting)) {
                *result = 1;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ItemWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_ItemWidget.data,
    qt_meta_data_ItemWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ItemWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ItemWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ItemWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ItemWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ItemWidget::selected()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ItemWidget::connecting()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_ListWidget_t {
    QByteArrayData data[6];
    char stringdata0[75];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ListWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ListWidget_t qt_meta_stringdata_ListWidget = {
    {
QT_MOC_LITERAL(0, 0, 10), // "ListWidget"
QT_MOC_LITERAL(1, 11, 13), // "connectDevice"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 11), // "ItemWidget*"
QT_MOC_LITERAL(4, 38, 14), // "slotSelectItem"
QT_MOC_LITERAL(5, 53, 21) // "slotsConnectingDevice"

    },
    "ListWidget\0connectDevice\0\0ItemWidget*\0"
    "slotSelectItem\0slotsConnectingDevice"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ListWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   32,    2, 0x08 /* Private */,
       5,    0,   33,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ListWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ListWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->connectDevice((*reinterpret_cast< ItemWidget*(*)>(_a[1]))); break;
        case 1: _t->slotSelectItem(); break;
        case 2: _t->slotsConnectingDevice(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ItemWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (ListWidget::*)(ItemWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ListWidget::connectDevice)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ListWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_ListWidget.data,
    qt_meta_data_ListWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ListWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ListWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ListWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ListWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ListWidget::connectDevice(ItemWidget * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_RefreButtonWidget_t {
    QByteArrayData data[3];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RefreButtonWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RefreButtonWidget_t qt_meta_stringdata_RefreButtonWidget = {
    {
QT_MOC_LITERAL(0, 0, 17), // "RefreButtonWidget"
QT_MOC_LITERAL(1, 18, 13), // "buttonClicked"
QT_MOC_LITERAL(2, 32, 0) // ""

    },
    "RefreButtonWidget\0buttonClicked\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RefreButtonWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,

       0        // eod
};

void RefreButtonWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RefreButtonWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->buttonClicked(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (RefreButtonWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RefreButtonWidget::buttonClicked)) {
                *result = 0;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject RefreButtonWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_RefreButtonWidget.data,
    qt_meta_data_RefreButtonWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RefreButtonWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RefreButtonWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RefreButtonWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int RefreButtonWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void RefreButtonWidget::buttonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
struct qt_meta_stringdata_MircastWidget_t {
    QByteArrayData data[28];
    char stringdata0[356];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MircastWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MircastWidget_t qt_meta_stringdata_MircastWidget = {
    {
QT_MOC_LITERAL(0, 0, 13), // "MircastWidget"
QT_MOC_LITERAL(1, 14, 11), // "closeServer"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 12), // "mircastState"
QT_MOC_LITERAL(4, 40, 5), // "state"
QT_MOC_LITERAL(5, 46, 3), // "msg"
QT_MOC_LITERAL(6, 50, 10), // "updateTime"
QT_MOC_LITERAL(7, 61, 4), // "time"
QT_MOC_LITERAL(8, 66, 16), // "updatePlayStatus"
QT_MOC_LITERAL(9, 83, 11), // "togglePopup"
QT_MOC_LITERAL(10, 95, 13), // "slotReadyRead"
QT_MOC_LITERAL(11, 109, 15), // "slotExitMircast"
QT_MOC_LITERAL(12, 125, 15), // "slotSeekMircast"
QT_MOC_LITERAL(13, 141, 15), // "slotPauseDlnaTp"
QT_MOC_LITERAL(14, 157, 21), // "slotRefreshBtnClicked"
QT_MOC_LITERAL(15, 179, 17), // "slotSearchTimeout"
QT_MOC_LITERAL(16, 197, 18), // "slotMircastTimeout"
QT_MOC_LITERAL(17, 216, 19), // "slotGetPositionInfo"
QT_MOC_LITERAL(18, 236, 16), // "DlnaPositionInfo"
QT_MOC_LITERAL(19, 253, 4), // "info"
QT_MOC_LITERAL(20, 258, 17), // "slotConnectDevice"
QT_MOC_LITERAL(21, 276, 11), // "ItemWidget*"
QT_MOC_LITERAL(22, 288, 11), // "pauseDlnaTp"
QT_MOC_LITERAL(23, 300, 10), // "playDlnaTp"
QT_MOC_LITERAL(24, 311, 10), // "seekDlnaTp"
QT_MOC_LITERAL(25, 322, 5), // "nSeek"
QT_MOC_LITERAL(26, 328, 10), // "stopDlnaTP"
QT_MOC_LITERAL(27, 339, 16) // "getPosInfoDlnaTp"

    },
    "MircastWidget\0closeServer\0\0mircastState\0"
    "state\0msg\0updateTime\0time\0updatePlayStatus\0"
    "togglePopup\0slotReadyRead\0slotExitMircast\0"
    "slotSeekMircast\0slotPauseDlnaTp\0"
    "slotRefreshBtnClicked\0slotSearchTimeout\0"
    "slotMircastTimeout\0slotGetPositionInfo\0"
    "DlnaPositionInfo\0info\0slotConnectDevice\0"
    "ItemWidget*\0pauseDlnaTp\0playDlnaTp\0"
    "seekDlnaTp\0nSeek\0stopDlnaTP\0"
    "getPosInfoDlnaTp"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MircastWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  114,    2, 0x06 /* Public */,
       3,    2,  115,    2, 0x06 /* Public */,
       3,    1,  120,    2, 0x26 /* Public | MethodCloned */,
       6,    1,  123,    2, 0x06 /* Public */,
       8,    0,  126,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,  127,    2, 0x0a /* Public */,
      10,    0,  128,    2, 0x0a /* Public */,
      11,    0,  129,    2, 0x0a /* Public */,
      12,    1,  130,    2, 0x0a /* Public */,
      13,    0,  133,    2, 0x0a /* Public */,
      14,    0,  134,    2, 0x0a /* Public */,
      15,    0,  135,    2, 0x0a /* Public */,
      16,    0,  136,    2, 0x0a /* Public */,
      17,    1,  137,    2, 0x0a /* Public */,
      20,    1,  140,    2, 0x0a /* Public */,
      22,    0,  143,    2, 0x0a /* Public */,
      23,    0,  144,    2, 0x0a /* Public */,
      24,    1,  145,    2, 0x0a /* Public */,
      26,    0,  148,    2, 0x0a /* Public */,
      27,    0,  149,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    4,    5,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void, 0x80000000 | 21,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MircastWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MircastWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->closeServer(); break;
        case 1: _t->mircastState((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 2: _t->mircastState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->updateTime((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->updatePlayStatus(); break;
        case 5: _t->togglePopup(); break;
        case 6: _t->slotReadyRead(); break;
        case 7: _t->slotExitMircast(); break;
        case 8: _t->slotSeekMircast((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->slotPauseDlnaTp(); break;
        case 10: _t->slotRefreshBtnClicked(); break;
        case 11: _t->slotSearchTimeout(); break;
        case 12: _t->slotMircastTimeout(); break;
        case 13: _t->slotGetPositionInfo((*reinterpret_cast< DlnaPositionInfo(*)>(_a[1]))); break;
        case 14: _t->slotConnectDevice((*reinterpret_cast< ItemWidget*(*)>(_a[1]))); break;
        case 15: _t->pauseDlnaTp(); break;
        case 16: _t->playDlnaTp(); break;
        case 17: _t->seekDlnaTp((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->stopDlnaTP(); break;
        case 19: _t->getPosInfoDlnaTp(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ItemWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MircastWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MircastWidget::closeServer)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MircastWidget::*)(int , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MircastWidget::mircastState)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (MircastWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MircastWidget::updateTime)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (MircastWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MircastWidget::updatePlayStatus)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MircastWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DFloatingWidget::staticMetaObject>(),
    qt_meta_stringdata_MircastWidget.data,
    qt_meta_data_MircastWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MircastWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MircastWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MircastWidget.stringdata0))
        return static_cast<void*>(this);
    return DFloatingWidget::qt_metacast(_clname);
}

int MircastWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFloatingWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void MircastWidget::closeServer()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MircastWidget::mircastState(int _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 3
void MircastWidget::updateTime(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void MircastWidget::updatePlayStatus()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
