/****************************************************************************
** Meta object code from reading C++ file 'platform_mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../common/platform/platform_mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'platform_mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__Platform_MessageWindow_t {
    QByteArrayData data[1];
    char stringdata0[28];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__Platform_MessageWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__Platform_MessageWindow_t qt_meta_stringdata_dmr__Platform_MessageWindow = {
    {
QT_MOC_LITERAL(0, 0, 27) // "dmr::Platform_MessageWindow"

    },
    "dmr::Platform_MessageWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__Platform_MessageWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::Platform_MessageWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::Platform_MessageWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dmr__Platform_MessageWindow.data,
    qt_meta_data_dmr__Platform_MessageWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::Platform_MessageWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_MessageWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__Platform_MessageWindow.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::Platform_MessageWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__Platform_MainWindow_t {
    QByteArrayData data[86];
    char stringdata0[1194];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__Platform_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__Platform_MainWindow_t qt_meta_stringdata_dmr__Platform_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 24), // "dmr::Platform_MainWindow"
QT_MOC_LITERAL(1, 25, 13), // "windowEntered"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 12), // "windowLeaved"
QT_MOC_LITERAL(4, 53, 11), // "initChanged"
QT_MOC_LITERAL(5, 65, 15), // "frameMenuEnable"
QT_MOC_LITERAL(6, 81, 19), // "playSpeedMenuEnable"
QT_MOC_LITERAL(7, 101, 18), // "subtitleMenuEnable"
QT_MOC_LITERAL(8, 120, 15), // "soundMenuEnable"
QT_MOC_LITERAL(9, 136, 9), // "WMChanged"
QT_MOC_LITERAL(10, 146, 4), // "isWM"
QT_MOC_LITERAL(11, 151, 4), // "play"
QT_MOC_LITERAL(12, 156, 14), // "QList<QString>"
QT_MOC_LITERAL(13, 171, 9), // "listFiles"
QT_MOC_LITERAL(14, 181, 19), // "updateProxyGeometry"
QT_MOC_LITERAL(15, 201, 18), // "suspendToolsWindow"
QT_MOC_LITERAL(16, 220, 17), // "resumeToolsWindow"
QT_MOC_LITERAL(17, 238, 16), // "checkOnlineState"
QT_MOC_LITERAL(18, 255, 9), // "bIsOnline"
QT_MOC_LITERAL(19, 265, 19), // "checkOnlineSubtitle"
QT_MOC_LITERAL(20, 285, 26), // "OnlineSubtitle::FailReason"
QT_MOC_LITERAL(21, 312, 6), // "reason"
QT_MOC_LITERAL(22, 319, 24), // "checkErrorMpvLogsChanged"
QT_MOC_LITERAL(23, 344, 7), // "sPrefix"
QT_MOC_LITERAL(24, 352, 5), // "sText"
QT_MOC_LITERAL(25, 358, 26), // "checkWarningMpvLogsChanged"
QT_MOC_LITERAL(26, 385, 26), // "slotdefaultplaymodechanged"
QT_MOC_LITERAL(27, 412, 4), // "sKey"
QT_MOC_LITERAL(28, 417, 5), // "value"
QT_MOC_LITERAL(29, 423, 16), // "onSetDecodeModel"
QT_MOC_LITERAL(30, 440, 3), // "key"
QT_MOC_LITERAL(31, 444, 15), // "onRefreshDecode"
QT_MOC_LITERAL(32, 460, 11), // "syncPostion"
QT_MOC_LITERAL(33, 472, 15), // "my_setStayOnTop"
QT_MOC_LITERAL(34, 488, 14), // "const QWidget*"
QT_MOC_LITERAL(35, 503, 7), // "pWidget"
QT_MOC_LITERAL(36, 511, 3), // "bOn"
QT_MOC_LITERAL(37, 515, 26), // "slotmousePressTimerTimeOut"
QT_MOC_LITERAL(38, 542, 22), // "slotPlayerStateChanged"
QT_MOC_LITERAL(39, 565, 22), // "slotFocusWindowChanged"
QT_MOC_LITERAL(40, 588, 14), // "slotFileLoaded"
QT_MOC_LITERAL(41, 603, 12), // "slotUrlpause"
QT_MOC_LITERAL(42, 616, 7), // "bStatus"
QT_MOC_LITERAL(43, 624, 15), // "slotFontChanged"
QT_MOC_LITERAL(44, 640, 4), // "font"
QT_MOC_LITERAL(45, 645, 15), // "slotMuteChanged"
QT_MOC_LITERAL(46, 661, 5), // "bMute"
QT_MOC_LITERAL(47, 667, 17), // "slotVolumeChanged"
QT_MOC_LITERAL(48, 685, 7), // "nVolume"
QT_MOC_LITERAL(49, 693, 13), // "slotWMChanged"
QT_MOC_LITERAL(50, 707, 3), // "msg"
QT_MOC_LITERAL(51, 711, 22), // "slotUpdateMircastState"
QT_MOC_LITERAL(52, 734, 5), // "state"
QT_MOC_LITERAL(53, 740, 15), // "slotExitMircast"
QT_MOC_LITERAL(54, 756, 7), // "setInit"
QT_MOC_LITERAL(55, 764, 5), // "bInit"
QT_MOC_LITERAL(56, 770, 15), // "menuItemInvoked"
QT_MOC_LITERAL(57, 786, 8), // "QAction*"
QT_MOC_LITERAL(58, 795, 7), // "pAction"
QT_MOC_LITERAL(59, 803, 17), // "onBindingsChanged"
QT_MOC_LITERAL(60, 821, 18), // "updateActionsState"
QT_MOC_LITERAL(61, 840, 16), // "animatePlayState"
QT_MOC_LITERAL(62, 857, 19), // "resizeByConstraints"
QT_MOC_LITERAL(63, 877, 14), // "bForceCentered"
QT_MOC_LITERAL(64, 892, 20), // "onWindowStateChanged"
QT_MOC_LITERAL(65, 913, 17), // "miniButtonClicked"
QT_MOC_LITERAL(66, 931, 3), // "sId"
QT_MOC_LITERAL(67, 935, 18), // "startBurstShooting"
QT_MOC_LITERAL(68, 954, 17), // "onBurstScreenshot"
QT_MOC_LITERAL(69, 972, 8), // "imgFrame"
QT_MOC_LITERAL(70, 981, 9), // "timestamp"
QT_MOC_LITERAL(71, 991, 26), // "delayedMouseReleaseHandler"
QT_MOC_LITERAL(72, 1018, 11), // "diskRemoved"
QT_MOC_LITERAL(73, 1030, 9), // "sDiskName"
QT_MOC_LITERAL(74, 1040, 17), // "sleepStateChanged"
QT_MOC_LITERAL(75, 1058, 6), // "bSleep"
QT_MOC_LITERAL(76, 1065, 16), // "lockStateChanged"
QT_MOC_LITERAL(77, 1082, 5), // "bLock"
QT_MOC_LITERAL(78, 1088, 14), // "onSysLockState"
QT_MOC_LITERAL(79, 1103, 11), // "serviceName"
QT_MOC_LITERAL(80, 1115, 9), // "key2value"
QT_MOC_LITERAL(81, 1125, 17), // "slotProperChanged"
QT_MOC_LITERAL(82, 1143, 15), // "slotUnsupported"
QT_MOC_LITERAL(83, 1159, 15), // "slotInvalidFile"
QT_MOC_LITERAL(84, 1175, 11), // "strFileName"
QT_MOC_LITERAL(85, 1187, 6) // "inited"

    },
    "dmr::Platform_MainWindow\0windowEntered\0"
    "\0windowLeaved\0initChanged\0frameMenuEnable\0"
    "playSpeedMenuEnable\0subtitleMenuEnable\0"
    "soundMenuEnable\0WMChanged\0isWM\0play\0"
    "QList<QString>\0listFiles\0updateProxyGeometry\0"
    "suspendToolsWindow\0resumeToolsWindow\0"
    "checkOnlineState\0bIsOnline\0"
    "checkOnlineSubtitle\0OnlineSubtitle::FailReason\0"
    "reason\0checkErrorMpvLogsChanged\0sPrefix\0"
    "sText\0checkWarningMpvLogsChanged\0"
    "slotdefaultplaymodechanged\0sKey\0value\0"
    "onSetDecodeModel\0key\0onRefreshDecode\0"
    "syncPostion\0my_setStayOnTop\0const QWidget*\0"
    "pWidget\0bOn\0slotmousePressTimerTimeOut\0"
    "slotPlayerStateChanged\0slotFocusWindowChanged\0"
    "slotFileLoaded\0slotUrlpause\0bStatus\0"
    "slotFontChanged\0font\0slotMuteChanged\0"
    "bMute\0slotVolumeChanged\0nVolume\0"
    "slotWMChanged\0msg\0slotUpdateMircastState\0"
    "state\0slotExitMircast\0setInit\0bInit\0"
    "menuItemInvoked\0QAction*\0pAction\0"
    "onBindingsChanged\0updateActionsState\0"
    "animatePlayState\0resizeByConstraints\0"
    "bForceCentered\0onWindowStateChanged\0"
    "miniButtonClicked\0sId\0startBurstShooting\0"
    "onBurstScreenshot\0imgFrame\0timestamp\0"
    "delayedMouseReleaseHandler\0diskRemoved\0"
    "sDiskName\0sleepStateChanged\0bSleep\0"
    "lockStateChanged\0bLock\0onSysLockState\0"
    "serviceName\0key2value\0slotProperChanged\0"
    "slotUnsupported\0slotInvalidFile\0"
    "strFileName\0inited"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__Platform_MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      51,   14, // methods
       1,  402, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  269,    2, 0x06 /* Public */,
       3,    0,  270,    2, 0x06 /* Public */,
       4,    0,  271,    2, 0x06 /* Public */,
       5,    1,  272,    2, 0x06 /* Public */,
       6,    1,  275,    2, 0x06 /* Public */,
       7,    1,  278,    2, 0x06 /* Public */,
       8,    1,  281,    2, 0x06 /* Public */,
       9,    1,  284,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,  287,    2, 0x0a /* Public */,
      14,    0,  290,    2, 0x0a /* Public */,
      15,    0,  291,    2, 0x0a /* Public */,
      16,    0,  292,    2, 0x0a /* Public */,
      17,    1,  293,    2, 0x0a /* Public */,
      19,    1,  296,    2, 0x0a /* Public */,
      22,    2,  299,    2, 0x0a /* Public */,
      25,    2,  304,    2, 0x0a /* Public */,
      26,    2,  309,    2, 0x0a /* Public */,
      29,    2,  314,    2, 0x0a /* Public */,
      31,    0,  319,    2, 0x0a /* Public */,
      32,    0,  320,    2, 0x0a /* Public */,
      33,    2,  321,    2, 0x0a /* Public */,
      37,    0,  326,    2, 0x0a /* Public */,
      38,    0,  327,    2, 0x0a /* Public */,
      39,    0,  328,    2, 0x0a /* Public */,
      40,    0,  329,    2, 0x0a /* Public */,
      41,    1,  330,    2, 0x0a /* Public */,
      43,    1,  333,    2, 0x0a /* Public */,
      45,    1,  336,    2, 0x0a /* Public */,
      47,    1,  339,    2, 0x0a /* Public */,
      49,    1,  342,    2, 0x0a /* Public */,
      51,    2,  345,    2, 0x0a /* Public */,
      53,    0,  350,    2, 0x0a /* Public */,
      54,    1,  351,    2, 0x09 /* Protected */,
      56,    1,  354,    2, 0x09 /* Protected */,
      59,    0,  357,    2, 0x09 /* Protected */,
      60,    0,  358,    2, 0x09 /* Protected */,
      61,    0,  359,    2, 0x09 /* Protected */,
      62,    1,  360,    2, 0x09 /* Protected */,
      62,    0,  363,    2, 0x29 /* Protected | MethodCloned */,
      64,    0,  364,    2, 0x09 /* Protected */,
      65,    1,  365,    2, 0x09 /* Protected */,
      67,    0,  368,    2, 0x09 /* Protected */,
      68,    2,  369,    2, 0x09 /* Protected */,
      71,    0,  374,    2, 0x09 /* Protected */,
      72,    1,  375,    2, 0x09 /* Protected */,
      74,    1,  378,    2, 0x09 /* Protected */,
      76,    1,  381,    2, 0x09 /* Protected */,
      78,    3,  384,    2, 0x09 /* Protected */,
      81,    3,  391,    2, 0x09 /* Protected */,
      82,    0,  398,    2, 0x09 /* Protected */,
      83,    1,  399,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   10,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   23,   24,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   23,   24,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   27,   28,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   30,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 34, QMetaType::Bool,   35,   36,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   42,
    QMetaType::Void, QMetaType::QFont,   44,
    QMetaType::Void, QMetaType::Bool,   46,
    QMetaType::Void, QMetaType::Int,   48,
    QMetaType::Void, QMetaType::QString,   50,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   52,   50,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   55,
    QMetaType::Void, 0x80000000 | 57,   58,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   63,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   66,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QImage, QMetaType::LongLong,   69,   70,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   73,
    QMetaType::Void, QMetaType::Bool,   75,
    QMetaType::Void, QMetaType::Bool,   77,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QStringList,   79,   80,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QStringList,    2,   80,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   84,

 // properties: name, type, flags
      85, QMetaType::Bool, 0x00495003,

 // properties: notify_signal_id
       2,

       0        // eod
};

void dmr::Platform_MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Platform_MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->windowEntered(); break;
        case 1: _t->windowLeaved(); break;
        case 2: _t->initChanged(); break;
        case 3: _t->frameMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->playSpeedMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->subtitleMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->soundMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->WMChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->play((*reinterpret_cast< const QList<QString>(*)>(_a[1]))); break;
        case 9: _t->updateProxyGeometry(); break;
        case 10: _t->suspendToolsWindow(); break;
        case 11: _t->resumeToolsWindow(); break;
        case 12: _t->checkOnlineState((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 13: _t->checkOnlineSubtitle((*reinterpret_cast< const OnlineSubtitle::FailReason(*)>(_a[1]))); break;
        case 14: _t->checkErrorMpvLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 15: _t->checkWarningMpvLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->slotdefaultplaymodechanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 17: _t->onSetDecodeModel((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 18: _t->onRefreshDecode(); break;
        case 19: _t->syncPostion(); break;
        case 20: _t->my_setStayOnTop((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 21: _t->slotmousePressTimerTimeOut(); break;
        case 22: _t->slotPlayerStateChanged(); break;
        case 23: _t->slotFocusWindowChanged(); break;
        case 24: _t->slotFileLoaded(); break;
        case 25: _t->slotUrlpause((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->slotFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 27: _t->slotMuteChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->slotVolumeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->slotWMChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 30: _t->slotUpdateMircastState((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 31: _t->slotExitMircast(); break;
        case 32: _t->setInit((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->menuItemInvoked((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 34: _t->onBindingsChanged(); break;
        case 35: _t->updateActionsState(); break;
        case 36: _t->animatePlayState(); break;
        case 37: _t->resizeByConstraints((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 38: _t->resizeByConstraints(); break;
        case 39: _t->onWindowStateChanged(); break;
        case 40: _t->miniButtonClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 41: _t->startBurstShooting(); break;
        case 42: _t->onBurstScreenshot((*reinterpret_cast< const QImage(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2]))); break;
        case 43: _t->delayedMouseReleaseHandler(); break;
        case 44: _t->diskRemoved((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 45: _t->sleepStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 46: _t->lockStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 47: _t->onSysLockState((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QVariantMap(*)>(_a[2])),(*reinterpret_cast< QStringList(*)>(_a[3]))); break;
        case 48: _t->slotProperChanged((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QVariantMap(*)>(_a[2])),(*reinterpret_cast< QStringList(*)>(_a[3]))); break;
        case 49: _t->slotUnsupported(); break;
        case 50: _t->slotInvalidFile((*reinterpret_cast< QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QString> >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Platform_MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::windowEntered)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Platform_MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::windowLeaved)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Platform_MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::initChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Platform_MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::frameMenuEnable)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Platform_MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::playSpeedMenuEnable)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Platform_MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::subtitleMenuEnable)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Platform_MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::soundMenuEnable)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Platform_MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_MainWindow::WMChanged)) {
                *result = 7;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Platform_MainWindow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->inited(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Platform_MainWindow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInit(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject dmr::Platform_MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<DMainWindow::staticMetaObject>(),
    qt_meta_stringdata_dmr__Platform_MainWindow.data,
    qt_meta_data_dmr__Platform_MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::Platform_MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__Platform_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return DMainWindow::qt_metacast(_clname);
}

int dmr::Platform_MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 51)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 51;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void dmr::Platform_MainWindow::windowEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::Platform_MainWindow::windowLeaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dmr::Platform_MainWindow::initChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::Platform_MainWindow::frameMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void dmr::Platform_MainWindow::playSpeedMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void dmr::Platform_MainWindow::subtitleMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void dmr::Platform_MainWindow::soundMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void dmr::Platform_MainWindow::WMChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
