/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../common/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__MessageWindow_t {
    QByteArrayData data[1];
    char stringdata0[19];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__MessageWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__MessageWindow_t qt_meta_stringdata_dmr__MessageWindow = {
    {
QT_MOC_LITERAL(0, 0, 18) // "dmr::MessageWindow"

    },
    "dmr::MessageWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__MessageWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::MessageWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::MessageWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dmr__MessageWindow.data,
    qt_meta_data_dmr__MessageWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::MessageWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::MessageWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__MessageWindow.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::MessageWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__MainWindow_t {
    QByteArrayData data[88];
    char stringdata0[1221];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__MainWindow_t qt_meta_stringdata_dmr__MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 15), // "dmr::MainWindow"
QT_MOC_LITERAL(1, 16, 13), // "windowEntered"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 12), // "windowLeaved"
QT_MOC_LITERAL(4, 44, 11), // "initChanged"
QT_MOC_LITERAL(5, 56, 15), // "frameMenuEnable"
QT_MOC_LITERAL(6, 72, 19), // "playSpeedMenuEnable"
QT_MOC_LITERAL(7, 92, 18), // "subtitleMenuEnable"
QT_MOC_LITERAL(8, 111, 15), // "soundMenuEnable"
QT_MOC_LITERAL(9, 127, 9), // "WMChanged"
QT_MOC_LITERAL(10, 137, 4), // "isWM"
QT_MOC_LITERAL(11, 142, 4), // "play"
QT_MOC_LITERAL(12, 147, 14), // "QList<QString>"
QT_MOC_LITERAL(13, 162, 9), // "listFiles"
QT_MOC_LITERAL(14, 172, 20), // "slotFinishedAddFiles"
QT_MOC_LITERAL(15, 193, 11), // "QList<QUrl>"
QT_MOC_LITERAL(16, 205, 19), // "updateProxyGeometry"
QT_MOC_LITERAL(17, 225, 18), // "suspendToolsWindow"
QT_MOC_LITERAL(18, 244, 17), // "resumeToolsWindow"
QT_MOC_LITERAL(19, 262, 16), // "checkOnlineState"
QT_MOC_LITERAL(20, 279, 9), // "bIsOnline"
QT_MOC_LITERAL(21, 289, 19), // "checkOnlineSubtitle"
QT_MOC_LITERAL(22, 309, 26), // "OnlineSubtitle::FailReason"
QT_MOC_LITERAL(23, 336, 6), // "reason"
QT_MOC_LITERAL(24, 343, 24), // "checkErrorMpvLogsChanged"
QT_MOC_LITERAL(25, 368, 7), // "sPrefix"
QT_MOC_LITERAL(26, 376, 5), // "sText"
QT_MOC_LITERAL(27, 382, 26), // "checkWarningMpvLogsChanged"
QT_MOC_LITERAL(28, 409, 26), // "slotdefaultplaymodechanged"
QT_MOC_LITERAL(29, 436, 4), // "sKey"
QT_MOC_LITERAL(30, 441, 5), // "value"
QT_MOC_LITERAL(31, 447, 16), // "onSetDecodeModel"
QT_MOC_LITERAL(32, 464, 3), // "key"
QT_MOC_LITERAL(33, 468, 15), // "onRefreshDecode"
QT_MOC_LITERAL(34, 484, 15), // "my_setStayOnTop"
QT_MOC_LITERAL(35, 500, 14), // "const QWidget*"
QT_MOC_LITERAL(36, 515, 7), // "pWidget"
QT_MOC_LITERAL(37, 523, 3), // "bOn"
QT_MOC_LITERAL(38, 527, 26), // "slotmousePressTimerTimeOut"
QT_MOC_LITERAL(39, 554, 22), // "slotPlayerStateChanged"
QT_MOC_LITERAL(40, 577, 22), // "slotFocusWindowChanged"
QT_MOC_LITERAL(41, 600, 14), // "slotFileLoaded"
QT_MOC_LITERAL(42, 615, 12), // "slotUrlpause"
QT_MOC_LITERAL(43, 628, 7), // "bStatus"
QT_MOC_LITERAL(44, 636, 15), // "slotFontChanged"
QT_MOC_LITERAL(45, 652, 4), // "font"
QT_MOC_LITERAL(46, 657, 15), // "slotMuteChanged"
QT_MOC_LITERAL(47, 673, 5), // "bMute"
QT_MOC_LITERAL(48, 679, 17), // "slotVolumeChanged"
QT_MOC_LITERAL(49, 697, 7), // "nVolume"
QT_MOC_LITERAL(50, 705, 13), // "slotWMChanged"
QT_MOC_LITERAL(51, 719, 3), // "msg"
QT_MOC_LITERAL(52, 723, 14), // "slotMediaError"
QT_MOC_LITERAL(53, 738, 22), // "slotUpdateMircastState"
QT_MOC_LITERAL(54, 761, 5), // "state"
QT_MOC_LITERAL(55, 767, 15), // "slotExitMircast"
QT_MOC_LITERAL(56, 783, 7), // "setInit"
QT_MOC_LITERAL(57, 791, 5), // "bInit"
QT_MOC_LITERAL(58, 797, 15), // "menuItemInvoked"
QT_MOC_LITERAL(59, 813, 8), // "QAction*"
QT_MOC_LITERAL(60, 822, 7), // "pAction"
QT_MOC_LITERAL(61, 830, 17), // "onBindingsChanged"
QT_MOC_LITERAL(62, 848, 18), // "updateActionsState"
QT_MOC_LITERAL(63, 867, 16), // "animatePlayState"
QT_MOC_LITERAL(64, 884, 19), // "resizeByConstraints"
QT_MOC_LITERAL(65, 904, 14), // "bForceCentered"
QT_MOC_LITERAL(66, 919, 20), // "onWindowStateChanged"
QT_MOC_LITERAL(67, 940, 17), // "miniButtonClicked"
QT_MOC_LITERAL(68, 958, 3), // "sId"
QT_MOC_LITERAL(69, 962, 18), // "startBurstShooting"
QT_MOC_LITERAL(70, 981, 17), // "onBurstScreenshot"
QT_MOC_LITERAL(71, 999, 8), // "imgFrame"
QT_MOC_LITERAL(72, 1008, 9), // "timestamp"
QT_MOC_LITERAL(73, 1018, 26), // "delayedMouseReleaseHandler"
QT_MOC_LITERAL(74, 1045, 11), // "diskRemoved"
QT_MOC_LITERAL(75, 1057, 9), // "sDiskName"
QT_MOC_LITERAL(76, 1067, 17), // "sleepStateChanged"
QT_MOC_LITERAL(77, 1085, 6), // "bSleep"
QT_MOC_LITERAL(78, 1092, 16), // "lockStateChanged"
QT_MOC_LITERAL(79, 1109, 5), // "bLock"
QT_MOC_LITERAL(80, 1115, 14), // "onSysLockState"
QT_MOC_LITERAL(81, 1130, 11), // "serviceName"
QT_MOC_LITERAL(82, 1142, 9), // "key2value"
QT_MOC_LITERAL(83, 1152, 17), // "slotProperChanged"
QT_MOC_LITERAL(84, 1170, 15), // "slotUnsupported"
QT_MOC_LITERAL(85, 1186, 15), // "slotInvalidFile"
QT_MOC_LITERAL(86, 1202, 11), // "strFileName"
QT_MOC_LITERAL(87, 1214, 6) // "inited"

    },
    "dmr::MainWindow\0windowEntered\0\0"
    "windowLeaved\0initChanged\0frameMenuEnable\0"
    "playSpeedMenuEnable\0subtitleMenuEnable\0"
    "soundMenuEnable\0WMChanged\0isWM\0play\0"
    "QList<QString>\0listFiles\0slotFinishedAddFiles\0"
    "QList<QUrl>\0updateProxyGeometry\0"
    "suspendToolsWindow\0resumeToolsWindow\0"
    "checkOnlineState\0bIsOnline\0"
    "checkOnlineSubtitle\0OnlineSubtitle::FailReason\0"
    "reason\0checkErrorMpvLogsChanged\0sPrefix\0"
    "sText\0checkWarningMpvLogsChanged\0"
    "slotdefaultplaymodechanged\0sKey\0value\0"
    "onSetDecodeModel\0key\0onRefreshDecode\0"
    "my_setStayOnTop\0const QWidget*\0pWidget\0"
    "bOn\0slotmousePressTimerTimeOut\0"
    "slotPlayerStateChanged\0slotFocusWindowChanged\0"
    "slotFileLoaded\0slotUrlpause\0bStatus\0"
    "slotFontChanged\0font\0slotMuteChanged\0"
    "bMute\0slotVolumeChanged\0nVolume\0"
    "slotWMChanged\0msg\0slotMediaError\0"
    "slotUpdateMircastState\0state\0"
    "slotExitMircast\0setInit\0bInit\0"
    "menuItemInvoked\0QAction*\0pAction\0"
    "onBindingsChanged\0updateActionsState\0"
    "animatePlayState\0resizeByConstraints\0"
    "bForceCentered\0onWindowStateChanged\0"
    "miniButtonClicked\0sId\0startBurstShooting\0"
    "onBurstScreenshot\0imgFrame\0timestamp\0"
    "delayedMouseReleaseHandler\0diskRemoved\0"
    "sDiskName\0sleepStateChanged\0bSleep\0"
    "lockStateChanged\0bLock\0onSysLockState\0"
    "serviceName\0key2value\0slotProperChanged\0"
    "slotUnsupported\0slotInvalidFile\0"
    "strFileName\0inited"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      52,   14, // methods
       1,  410, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  274,    2, 0x06 /* Public */,
       3,    0,  275,    2, 0x06 /* Public */,
       4,    0,  276,    2, 0x06 /* Public */,
       5,    1,  277,    2, 0x06 /* Public */,
       6,    1,  280,    2, 0x06 /* Public */,
       7,    1,  283,    2, 0x06 /* Public */,
       8,    1,  286,    2, 0x06 /* Public */,
       9,    1,  289,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    1,  292,    2, 0x0a /* Public */,
      14,    1,  295,    2, 0x0a /* Public */,
      16,    0,  298,    2, 0x0a /* Public */,
      17,    0,  299,    2, 0x0a /* Public */,
      18,    0,  300,    2, 0x0a /* Public */,
      19,    1,  301,    2, 0x0a /* Public */,
      21,    1,  304,    2, 0x0a /* Public */,
      24,    2,  307,    2, 0x0a /* Public */,
      27,    2,  312,    2, 0x0a /* Public */,
      28,    2,  317,    2, 0x0a /* Public */,
      31,    2,  322,    2, 0x0a /* Public */,
      33,    0,  327,    2, 0x0a /* Public */,
      34,    2,  328,    2, 0x0a /* Public */,
      38,    0,  333,    2, 0x0a /* Public */,
      39,    0,  334,    2, 0x0a /* Public */,
      40,    0,  335,    2, 0x0a /* Public */,
      41,    0,  336,    2, 0x0a /* Public */,
      42,    1,  337,    2, 0x0a /* Public */,
      44,    1,  340,    2, 0x0a /* Public */,
      46,    1,  343,    2, 0x0a /* Public */,
      48,    1,  346,    2, 0x0a /* Public */,
      50,    1,  349,    2, 0x0a /* Public */,
      52,    0,  352,    2, 0x0a /* Public */,
      53,    2,  353,    2, 0x0a /* Public */,
      55,    0,  358,    2, 0x0a /* Public */,
      56,    1,  359,    2, 0x09 /* Protected */,
      58,    1,  362,    2, 0x09 /* Protected */,
      61,    0,  365,    2, 0x09 /* Protected */,
      62,    0,  366,    2, 0x09 /* Protected */,
      63,    0,  367,    2, 0x09 /* Protected */,
      64,    1,  368,    2, 0x09 /* Protected */,
      64,    0,  371,    2, 0x29 /* Protected | MethodCloned */,
      66,    0,  372,    2, 0x09 /* Protected */,
      67,    1,  373,    2, 0x09 /* Protected */,
      69,    0,  376,    2, 0x09 /* Protected */,
      70,    2,  377,    2, 0x09 /* Protected */,
      73,    0,  382,    2, 0x09 /* Protected */,
      74,    1,  383,    2, 0x09 /* Protected */,
      76,    1,  386,    2, 0x09 /* Protected */,
      78,    1,  389,    2, 0x09 /* Protected */,
      80,    3,  392,    2, 0x09 /* Protected */,
      83,    3,  399,    2, 0x09 /* Protected */,
      84,    0,  406,    2, 0x09 /* Protected */,
      85,    1,  407,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,   10,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 12,   13,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   20,
    QMetaType::Void, 0x80000000 | 22,   23,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   25,   26,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   25,   26,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   29,   30,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   32,   30,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 35, QMetaType::Bool,   36,   37,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   43,
    QMetaType::Void, QMetaType::QFont,   45,
    QMetaType::Void, QMetaType::Bool,   47,
    QMetaType::Void, QMetaType::Int,   49,
    QMetaType::Void, QMetaType::QString,   51,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,   54,   51,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   57,
    QMetaType::Void, 0x80000000 | 59,   60,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   65,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   68,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QImage, QMetaType::LongLong,   71,   72,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   75,
    QMetaType::Void, QMetaType::Bool,   77,
    QMetaType::Void, QMetaType::Bool,   79,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QStringList,   81,   82,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariantMap, QMetaType::QStringList,    2,   82,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   86,

 // properties: name, type, flags
      87, QMetaType::Bool, 0x00495003,

 // properties: notify_signal_id
       2,

       0        // eod
};

void dmr::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->windowEntered(); break;
        case 1: _t->windowLeaved(); break;
        case 2: _t->initChanged(); break;
        case 3: _t->frameMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->playSpeedMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->subtitleMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->soundMenuEnable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->WMChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->play((*reinterpret_cast< const QList<QString>(*)>(_a[1]))); break;
        case 9: _t->slotFinishedAddFiles((*reinterpret_cast< QList<QUrl>(*)>(_a[1]))); break;
        case 10: _t->updateProxyGeometry(); break;
        case 11: _t->suspendToolsWindow(); break;
        case 12: _t->resumeToolsWindow(); break;
        case 13: _t->checkOnlineState((*reinterpret_cast< const bool(*)>(_a[1]))); break;
        case 14: _t->checkOnlineSubtitle((*reinterpret_cast< const OnlineSubtitle::FailReason(*)>(_a[1]))); break;
        case 15: _t->checkErrorMpvLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 16: _t->checkWarningMpvLogsChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 17: _t->slotdefaultplaymodechanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 18: _t->onSetDecodeModel((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 19: _t->onRefreshDecode(); break;
        case 20: _t->my_setStayOnTop((*reinterpret_cast< const QWidget*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 21: _t->slotmousePressTimerTimeOut(); break;
        case 22: _t->slotPlayerStateChanged(); break;
        case 23: _t->slotFocusWindowChanged(); break;
        case 24: _t->slotFileLoaded(); break;
        case 25: _t->slotUrlpause((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->slotFontChanged((*reinterpret_cast< const QFont(*)>(_a[1]))); break;
        case 27: _t->slotMuteChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->slotVolumeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->slotWMChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 30: _t->slotMediaError(); break;
        case 31: _t->slotUpdateMircastState((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 32: _t->slotExitMircast(); break;
        case 33: _t->setInit((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 34: _t->menuItemInvoked((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 35: _t->onBindingsChanged(); break;
        case 36: _t->updateActionsState(); break;
        case 37: _t->animatePlayState(); break;
        case 38: _t->resizeByConstraints((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->resizeByConstraints(); break;
        case 40: _t->onWindowStateChanged(); break;
        case 41: _t->miniButtonClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 42: _t->startBurstShooting(); break;
        case 43: _t->onBurstScreenshot((*reinterpret_cast< const QImage(*)>(_a[1])),(*reinterpret_cast< qint64(*)>(_a[2]))); break;
        case 44: _t->delayedMouseReleaseHandler(); break;
        case 45: _t->diskRemoved((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 46: _t->sleepStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 47: _t->lockStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 48: _t->onSysLockState((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QVariantMap(*)>(_a[2])),(*reinterpret_cast< QStringList(*)>(_a[3]))); break;
        case 49: _t->slotProperChanged((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QVariantMap(*)>(_a[2])),(*reinterpret_cast< QStringList(*)>(_a[3]))); break;
        case 50: _t->slotUnsupported(); break;
        case 51: _t->slotInvalidFile((*reinterpret_cast< QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QString> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::windowEntered)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::windowLeaved)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::initChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::frameMenuEnable)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::playSpeedMenuEnable)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::subtitleMenuEnable)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::soundMenuEnable)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::WMChanged)) {
                *result = 7;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->inited(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInit(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject dmr::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<DMainWindow::staticMetaObject>(),
    qt_meta_stringdata_dmr__MainWindow.data,
    qt_meta_data_dmr__MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__MainWindow.stringdata0))
        return static_cast<void*>(this);
    return DMainWindow::qt_metacast(_clname);
}

int dmr::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 52)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 52;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void dmr::MainWindow::windowEntered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::MainWindow::windowLeaved()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dmr::MainWindow::initChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::MainWindow::frameMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void dmr::MainWindow::playSpeedMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void dmr::MainWindow::subtitleMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void dmr::MainWindow::soundMenuEnable(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void dmr::MainWindow::WMChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
