/****************************************************************************
** Meta object code from reading C++ file 'platform_toolbox_proxy.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../widgets/platform/platform_toolbox_proxy.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'platform_toolbox_proxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dmr__Platform_ImageItem_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__Platform_ImageItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__Platform_ImageItem_t qt_meta_stringdata_dmr__Platform_ImageItem = {
    {
QT_MOC_LITERAL(0, 0, 23) // "dmr::Platform_ImageItem"

    },
    "dmr::Platform_ImageItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__Platform_ImageItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::Platform_ImageItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::Platform_ImageItem::staticMetaObject = { {
    QMetaObject::SuperData::link<DLabel::staticMetaObject>(),
    qt_meta_stringdata_dmr__Platform_ImageItem.data,
    qt_meta_data_dmr__Platform_ImageItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::Platform_ImageItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_ImageItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__Platform_ImageItem.stringdata0))
        return static_cast<void*>(this);
    return DLabel::qt_metacast(_clname);
}

int dmr::Platform_ImageItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DLabel::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__Platform_IndicatorItem_t {
    QByteArrayData data[1];
    char stringdata0[28];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__Platform_IndicatorItem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__Platform_IndicatorItem_t qt_meta_stringdata_dmr__Platform_IndicatorItem = {
    {
QT_MOC_LITERAL(0, 0, 27) // "dmr::Platform_IndicatorItem"

    },
    "dmr::Platform_IndicatorItem"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__Platform_IndicatorItem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void dmr::Platform_IndicatorItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject dmr::Platform_IndicatorItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_dmr__Platform_IndicatorItem.data,
    qt_meta_data_dmr__Platform_IndicatorItem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::Platform_IndicatorItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_IndicatorItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__Platform_IndicatorItem.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int dmr::Platform_IndicatorItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_dmr__Platform_ToolboxProxy_t {
    QByteArrayData data[51];
    char stringdata0[749];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__Platform_ToolboxProxy_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__Platform_ToolboxProxy_t qt_meta_stringdata_dmr__Platform_ToolboxProxy = {
    {
QT_MOC_LITERAL(0, 0, 26), // "dmr::Platform_ToolboxProxy"
QT_MOC_LITERAL(1, 27, 16), // "sigVolumeChanged"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 4), // "int&"
QT_MOC_LITERAL(4, 50, 7), // "nVolume"
QT_MOC_LITERAL(5, 58, 19), // "sigMuteStateChanged"
QT_MOC_LITERAL(6, 78, 5), // "bool&"
QT_MOC_LITERAL(7, 84, 5), // "bMute"
QT_MOC_LITERAL(8, 90, 14), // "sigUnsupported"
QT_MOC_LITERAL(9, 105, 15), // "sigMircastState"
QT_MOC_LITERAL(10, 121, 14), // "finishLoadSlot"
QT_MOC_LITERAL(11, 136, 4), // "size"
QT_MOC_LITERAL(12, 141, 16), // "setthumbnailmode"
QT_MOC_LITERAL(13, 158, 15), // "updateFullState"
QT_MOC_LITERAL(14, 174, 17), // "slotUpdateMircast"
QT_MOC_LITERAL(15, 192, 13), // "buttonClicked"
QT_MOC_LITERAL(16, 206, 2), // "id"
QT_MOC_LITERAL(17, 209, 11), // "buttonEnter"
QT_MOC_LITERAL(18, 221, 11), // "buttonLeave"
QT_MOC_LITERAL(19, 233, 15), // "updatePlayState"
QT_MOC_LITERAL(20, 249, 19), // "updateMovieProgress"
QT_MOC_LITERAL(21, 269, 18), // "updateButtonStates"
QT_MOC_LITERAL(22, 288, 17), // "updateTimeVisible"
QT_MOC_LITERAL(23, 306, 7), // "visible"
QT_MOC_LITERAL(24, 314, 20), // "progressHoverChanged"
QT_MOC_LITERAL(25, 335, 1), // "v"
QT_MOC_LITERAL(26, 337, 18), // "updateHoverPreview"
QT_MOC_LITERAL(27, 356, 3), // "url"
QT_MOC_LITERAL(28, 360, 4), // "secs"
QT_MOC_LITERAL(29, 365, 8), // "waitPlay"
QT_MOC_LITERAL(30, 374, 20), // "slotThemeTypeChanged"
QT_MOC_LITERAL(31, 395, 16), // "slotLeavePreview"
QT_MOC_LITERAL(32, 412, 19), // "slotHidePreviewTime"
QT_MOC_LITERAL(33, 432, 17), // "slotSliderPressed"
QT_MOC_LITERAL(34, 450, 18), // "slotSliderReleased"
QT_MOC_LITERAL(35, 469, 19), // "slotBaseMuteChanged"
QT_MOC_LITERAL(36, 489, 2), // "sk"
QT_MOC_LITERAL(37, 492, 3), // "val"
QT_MOC_LITERAL(38, 496, 23), // "slotVolumeButtonClicked"
QT_MOC_LITERAL(39, 520, 14), // "slotFileLoaded"
QT_MOC_LITERAL(40, 535, 18), // "slotElapsedChanged"
QT_MOC_LITERAL(41, 554, 27), // "slotApplicationStateChanged"
QT_MOC_LITERAL(42, 582, 20), // "Qt::ApplicationState"
QT_MOC_LITERAL(43, 603, 1), // "e"
QT_MOC_LITERAL(44, 605, 23), // "slotPlayListStateChange"
QT_MOC_LITERAL(45, 629, 10), // "isShortcut"
QT_MOC_LITERAL(46, 640, 26), // "slotUpdateThumbnailTimeOut"
QT_MOC_LITERAL(47, 667, 24), // "slotProAnimationFinished"
QT_MOC_LITERAL(48, 692, 17), // "slotVolumeChanged"
QT_MOC_LITERAL(49, 710, 20), // "slotMuteStateChanged"
QT_MOC_LITERAL(50, 731, 17) // "updateMircastTime"

    },
    "dmr::Platform_ToolboxProxy\0sigVolumeChanged\0"
    "\0int&\0nVolume\0sigMuteStateChanged\0"
    "bool&\0bMute\0sigUnsupported\0sigMircastState\0"
    "finishLoadSlot\0size\0setthumbnailmode\0"
    "updateFullState\0slotUpdateMircast\0"
    "buttonClicked\0id\0buttonEnter\0buttonLeave\0"
    "updatePlayState\0updateMovieProgress\0"
    "updateButtonStates\0updateTimeVisible\0"
    "visible\0progressHoverChanged\0v\0"
    "updateHoverPreview\0url\0secs\0waitPlay\0"
    "slotThemeTypeChanged\0slotLeavePreview\0"
    "slotHidePreviewTime\0slotSliderPressed\0"
    "slotSliderReleased\0slotBaseMuteChanged\0"
    "sk\0val\0slotVolumeButtonClicked\0"
    "slotFileLoaded\0slotElapsedChanged\0"
    "slotApplicationStateChanged\0"
    "Qt::ApplicationState\0e\0slotPlayListStateChange\0"
    "isShortcut\0slotUpdateThumbnailTimeOut\0"
    "slotProAnimationFinished\0slotVolumeChanged\0"
    "slotMuteStateChanged\0updateMircastTime"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__Platform_ToolboxProxy[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      34,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  184,    2, 0x06 /* Public */,
       5,    1,  187,    2, 0x06 /* Public */,
       8,    0,  190,    2, 0x06 /* Public */,
       9,    2,  191,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    1,  196,    2, 0x0a /* Public */,
      12,    0,  199,    2, 0x0a /* Public */,
      13,    0,  200,    2, 0x0a /* Public */,
      14,    2,  201,    2, 0x0a /* Public */,
      15,    1,  206,    2, 0x09 /* Protected */,
      17,    0,  209,    2, 0x09 /* Protected */,
      18,    0,  210,    2, 0x09 /* Protected */,
      19,    0,  211,    2, 0x09 /* Protected */,
      20,    0,  212,    2, 0x09 /* Protected */,
      21,    0,  213,    2, 0x09 /* Protected */,
      22,    1,  214,    2, 0x09 /* Protected */,
      24,    1,  217,    2, 0x09 /* Protected */,
      26,    2,  220,    2, 0x09 /* Protected */,
      29,    0,  225,    2, 0x09 /* Protected */,
      30,    0,  226,    2, 0x09 /* Protected */,
      31,    0,  227,    2, 0x09 /* Protected */,
      32,    0,  228,    2, 0x09 /* Protected */,
      33,    0,  229,    2, 0x09 /* Protected */,
      34,    0,  230,    2, 0x09 /* Protected */,
      35,    2,  231,    2, 0x09 /* Protected */,
      38,    0,  236,    2, 0x09 /* Protected */,
      39,    0,  237,    2, 0x09 /* Protected */,
      40,    0,  238,    2, 0x09 /* Protected */,
      41,    1,  239,    2, 0x09 /* Protected */,
      44,    1,  242,    2, 0x09 /* Protected */,
      46,    0,  245,    2, 0x09 /* Protected */,
      47,    0,  246,    2, 0x09 /* Protected */,
      48,    1,  247,    2, 0x09 /* Protected */,
      49,    1,  250,    2, 0x09 /* Protected */,
      50,    1,  253,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    2,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QSize,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QString,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   23,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Void, QMetaType::QUrl, QMetaType::Int,   27,   28,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant,   36,   37,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 42,   43,
    QMetaType::Void, QMetaType::Bool,   45,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void, QMetaType::Bool,    7,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void dmr::Platform_ToolboxProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Platform_ToolboxProxy *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->sigVolumeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->sigMuteStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->sigUnsupported(); break;
        case 3: _t->sigMircastState((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 4: _t->finishLoadSlot((*reinterpret_cast< QSize(*)>(_a[1]))); break;
        case 5: _t->setthumbnailmode(); break;
        case 6: _t->updateFullState(); break;
        case 7: _t->slotUpdateMircast((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 8: _t->buttonClicked((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 9: _t->buttonEnter(); break;
        case 10: _t->buttonLeave(); break;
        case 11: _t->updatePlayState(); break;
        case 12: _t->updateMovieProgress(); break;
        case 13: _t->updateButtonStates(); break;
        case 14: _t->updateTimeVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->progressHoverChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->updateHoverPreview((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 17: _t->waitPlay(); break;
        case 18: _t->slotThemeTypeChanged(); break;
        case 19: _t->slotLeavePreview(); break;
        case 20: _t->slotHidePreviewTime(); break;
        case 21: _t->slotSliderPressed(); break;
        case 22: _t->slotSliderReleased(); break;
        case 23: _t->slotBaseMuteChanged((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2]))); break;
        case 24: _t->slotVolumeButtonClicked(); break;
        case 25: _t->slotFileLoaded(); break;
        case 26: _t->slotElapsedChanged(); break;
        case 27: _t->slotApplicationStateChanged((*reinterpret_cast< Qt::ApplicationState(*)>(_a[1]))); break;
        case 28: _t->slotPlayListStateChange((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 29: _t->slotUpdateThumbnailTimeOut(); break;
        case 30: _t->slotProAnimationFinished(); break;
        case 31: _t->slotVolumeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 32: _t->slotMuteStateChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 33: _t->updateMircastTime((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Platform_ToolboxProxy::*)(int & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_ToolboxProxy::sigVolumeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Platform_ToolboxProxy::*)(bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_ToolboxProxy::sigMuteStateChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Platform_ToolboxProxy::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_ToolboxProxy::sigUnsupported)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Platform_ToolboxProxy::*)(int , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_ToolboxProxy::sigMircastState)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::Platform_ToolboxProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<DFloatingWidget::staticMetaObject>(),
    qt_meta_stringdata_dmr__Platform_ToolboxProxy.data,
    qt_meta_data_dmr__Platform_ToolboxProxy,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::Platform_ToolboxProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_ToolboxProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__Platform_ToolboxProxy.stringdata0))
        return static_cast<void*>(this);
    return DFloatingWidget::qt_metacast(_clname);
}

int dmr::Platform_ToolboxProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DFloatingWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void dmr::Platform_ToolboxProxy::sigVolumeChanged(int & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dmr::Platform_ToolboxProxy::sigMuteStateChanged(bool & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void dmr::Platform_ToolboxProxy::sigUnsupported()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dmr::Platform_ToolboxProxy::sigMircastState(int _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
struct qt_meta_stringdata_dmr__Platform_viewProgBarLoad_t {
    QByteArrayData data[8];
    char stringdata0[109];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dmr__Platform_viewProgBarLoad_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dmr__Platform_viewProgBarLoad_t qt_meta_stringdata_dmr__Platform_viewProgBarLoad = {
    {
QT_MOC_LITERAL(0, 0, 29), // "dmr::Platform_viewProgBarLoad"
QT_MOC_LITERAL(1, 30, 16), // "leaveViewProgBar"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 12), // "hoverChanged"
QT_MOC_LITERAL(4, 61, 11), // "sliderMoved"
QT_MOC_LITERAL(5, 73, 14), // "sigFinishiLoad"
QT_MOC_LITERAL(6, 88, 4), // "size"
QT_MOC_LITERAL(7, 93, 15) // "loadViewProgBar"

    },
    "dmr::Platform_viewProgBarLoad\0"
    "leaveViewProgBar\0\0hoverChanged\0"
    "sliderMoved\0sigFinishiLoad\0size\0"
    "loadViewProgBar"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dmr__Platform_viewProgBarLoad[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    1,   40,    2, 0x06 /* Public */,
       4,    1,   43,    2, 0x06 /* Public */,
       5,    1,   46,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   49,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QSize,    6,

 // slots: parameters
    QMetaType::Void, QMetaType::QSize,    6,

       0        // eod
};

void dmr::Platform_viewProgBarLoad::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Platform_viewProgBarLoad *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->leaveViewProgBar(); break;
        case 1: _t->hoverChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->sliderMoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->sigFinishiLoad((*reinterpret_cast< QSize(*)>(_a[1]))); break;
        case 4: _t->loadViewProgBar((*reinterpret_cast< QSize(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Platform_viewProgBarLoad::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_viewProgBarLoad::leaveViewProgBar)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Platform_viewProgBarLoad::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_viewProgBarLoad::hoverChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Platform_viewProgBarLoad::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_viewProgBarLoad::sliderMoved)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Platform_viewProgBarLoad::*)(QSize );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Platform_viewProgBarLoad::sigFinishiLoad)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dmr::Platform_viewProgBarLoad::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_meta_stringdata_dmr__Platform_viewProgBarLoad.data,
    qt_meta_data_dmr__Platform_viewProgBarLoad,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dmr::Platform_viewProgBarLoad::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::Platform_viewProgBarLoad::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dmr__Platform_viewProgBarLoad.stringdata0))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int dmr::Platform_viewProgBarLoad::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dmr::Platform_viewProgBarLoad::leaveViewProgBar()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::Platform_viewProgBarLoad::hoverChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void dmr::Platform_viewProgBarLoad::sliderMoved(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void dmr::Platform_viewProgBarLoad::sigFinishiLoad(QSize _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
